from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``en_US`` locale.

    Word list is based on the source(s) below, and some words have been removed
    to make the word list appropriate for public testing.

    Sources:

    - https://www.educall.com.tr/blog/post/500-most-common-english-verbs
    - http://www.ef.edu/english-resources/english-vocabulary/top-1000-words/
    - https://www.talkenglish.com/vocabulary/top-1500-nouns.aspx
    - https://www.talkenglish.com/vocabulary/top-250-adverbs.aspx
    - https://www.talkenglish.com/vocabulary/top-500-adjectives.aspx
    """

    word_list = (
        "a",
        "ability",
        "able",
        "about",
        "above",
        "accept",
        "according",
        "account",
        "across",
        "act",
        "action",
        "activity",
        "actually",
        "add",
        "address",
        "administration",
        "admit",
        "adult",
        "affect",
        "after",
        "again",
        "against",
        "age",
        "agency",
        "agent",
        "ago",
        "agree",
        "agreement",
        "ahead",
        "air",
        "all",
        "allow",
        "almost",
        "alone",
        "along",
        "already",
        "also",
        "although",
        "always",
        "American",
        "among",
        "amount",
        "analysis",
        "and",
        "animal",
        "another",
        "answer",
        "any",
        "anyone",
        "anything",
        "appear",
        "apply",
        "approach",
        "area",
        "argue",
        "arm",
        "around",
        "arrive",
        "art",
        "article",
        "artist",
        "as",
        "ask",
        "assume",
        "at",
        "attack",
        "attention",
        "attorney",
        "audience",
        "author",
        "authority",
        "available",
        "avoid",
        "away",
        "baby",
        "back",
        "bad",
        "bag",
        "ball",
        "bank",
        "bar",
        "base",
        "be",
        "beat",
        "beautiful",
        "because",
        "become",
        "bed",
        "before",
        "begin",
        "behavior",
        "behind",
        "believe",
        "benefit",
        "best",
        "better",
        "between",
        "beyond",
        "big",
        "bill",
        "billion",
        "bit",
        "black",
        "blood",
        "blue",
        "board",
        "body",
        "book",
        "born",
        "both",
        "box",
        "boy",
        "break",
        "bring",
        "brother",
        "budget",
        "build",
        "building",
        "business",
        "but",
        "buy",
        "by",
        "call",
        "camera",
        "campaign",
        "can",
        "candidate",
        "capital",
        "car",
        "card",
        "care",
        "career",
        "carry",
        "case",
        "catch",
        "cause",
        "cell",
        "center",
        "central",
        "century",
        "certain",
        "certainly",
        "chair",
        "challenge",
        "chance",
        "change",
        "character",
        "charge",
        "check",
        "child",
        "choice",
        "choose",
        "church",
        "citizen",
        "city",
        "civil",
        "claim",
        "class",
        "clear",
        "clearly",
        "close",
        "coach",
        "cold",
        "collection",
        "college",
        "color",
        "commercial",
        "common",
        "community",
        "company",
        "compare",
        "computer",
        "concern",
        "condition",
        "conference",
        "Congress",
        "consider",
        "consumer",
        "contain",
        "continue",
        "control",
        "cost",
        "could",
        "country",
        "couple",
        "course",
        "court",
        "cover",
        "create",
        "crime",
        "cultural",
        "culture",
        "cup",
        "current",
        "customer",
        "cut",
        "dark",
        "data",
        "daughter",
        "day",
        "deal",
        "debate",
        "decade",
        "decide",
        "decision",
        "deep",
        "defense",
        "degree",
        "Democrat",
        "democratic",
        "describe",
        "design",
        "despite",
        "detail",
        "determine",
        "develop",
        "development",
        "difference",
        "different",
        "difficult",
        "dinner",
        "direction",
        "director",
        "discover",
        "discuss",
        "discussion",
        "do",
        "doctor",
        "dog",
        "door",
        "down",
        "draw",
        "dream",
        "drive",
        "drop",
        "drug",
        "during",
        "each",
        "early",
        "east",
        "easy",
        "eat",
        "economic",
        "economy",
        "edge",
        "education",
        "effect",
        "effort",
        "eight",
        "either",
        "election",
        "else",
        "employee",
        "end",
        "energy",
        "enjoy",
        "enough",
        "enter",
        "entire",
        "environment",
        "environmental",
        "especially",
        "establish",
        "even",
        "evening",
        "event",
        "ever",
        "every",
        "everybody",
        "everyone",
        "everything",
        "evidence",
        "exactly",
        "example",
        "executive",
        "exist",
        "expect",
        "experience",
        "expert",
        "explain",
        "eye",
        "face",
        "fact",
        "factor",
        "fall",
        "family",
        "far",
        "fast",
        "father",
        "fear",
        "federal",
        "feel",
        "feeling",
        "few",
        "field",
        "fight",
        "figure",
        "fill",
        "film",
        "final",
        "finally",
        "financial",
        "find",
        "fine",
        "finish",
        "fire",
        "firm",
        "first",
        "fish",
        "five",
        "floor",
        "fly",
        "focus",
        "follow",
        "food",
        "foot",
        "for",
        "force",
        "foreign",
        "forget",
        "form",
        "former",
        "forward",
        "four",
        "free",
        "friend",
        "from",
        "front",
        "full",
        "fund",
        "future",
        "game",
        "garden",
        "gas",
        "general",
        "generation",
        "get",
        "girl",
        "give",
        "glass",
        "go",
        "goal",
        "good",
        "government",
        "great",
        "green",
        "ground",
        "group",
        "grow",
        "growth",
        "guess",
        "gun",
        "guy",
        "hair",
        "half",
        "hand",
        "happen",
        "happy",
        "hard",
        "have",
        "he",
        "head",
        "health",
        "hear",
        "heart",
        "heavy",
        "help",
        "her",
        "here",
        "herself",
        "high",
        "him",
        "himself",
        "his",
        "history",
        "hit",
        "hold",
        "home",
        "hope",
        "hospital",
        "hot",
        "hotel",
        "hour",
        "house",
        "how",
        "however",
        "huge",
        "human",
        "hundred",
        "husband",
        "I",
        "idea",
        "identify",
        "if",
        "image",
        "imagine",
        "impact",
        "important",
        "improve",
        "in",
        "include",
        "including",
        "increase",
        "indeed",
        "indicate",
        "individual",
        "industry",
        "information",
        "inside",
        "instead",
        "institution",
        "interest",
        "interesting",
        "international",
        "interview",
        "into",
        "investment",
        "involve",
        "issue",
        "it",
        "item",
        "its",
        "itself",
        "job",
        "join",
        "just",
        "keep",
        "key",
        "kid",
        "kind",
        "kitchen",
        "know",
        "knowledge",
        "land",
        "language",
        "large",
        "last",
        "late",
        "later",
        "laugh",
        "law",
        "lawyer",
        "lay",
        "lead",
        "leader",
        "learn",
        "least",
        "leave",
        "left",
        "leg",
        "less",
        "let",
        "letter",
        "level",
        "life",
        "light",
        "like",
        "likely",
        "line",
        "list",
        "listen",
        "little",
        "live",
        "local",
        "long",
        "look",
        "lose",
        "loss",
        "lot",
        "low",
        "machine",
        "magazine",
        "main",
        "maintain",
        "major",
        "majority",
        "make",
        "man",
        "manage",
        "management",
        "manager",
        "many",
        "market",
        "marriage",
        "material",
        "matter",
        "may",
        "maybe",
        "me",
        "mean",
        "measure",
        "media",
        "medical",
        "meet",
        "meeting",
        "member",
        "memory",
        "mention",
        "message",
        "method",
        "middle",
        "might",
        "military",
        "million",
        "mind",
        "minute",
        "miss",
        "mission",
        "model",
        "modern",
        "moment",
        "money",
        "month",
        "more",
        "morning",
        "most",
        "mother",
        "mouth",
        "move",
        "movement",
        "movie",
        "Mr",
        "Mrs",
        "much",
        "music",
        "must",
        "my",
        "myself",
        "name",
        "nation",
        "national",
        "natural",
        "nature",
        "near",
        "nearly",
        "necessary",
        "need",
        "network",
        "never",
        "new",
        "news",
        "newspaper",
        "next",
        "nice",
        "night",
        "no",
        "none",
        "nor",
        "north",
        "not",
        "note",
        "nothing",
        "notice",
        "now",
        "number",
        "occur",
        "of",
        "off",
        "offer",
        "office",
        "officer",
        "official",
        "often",
        "oil",
        "ok",
        "old",
        "on",
        "once",
        "one",
        "only",
        "onto",
        "open",
        "operation",
        "opportunity",
        "option",
        "or",
        "order",
        "organization",
        "other",
        "others",
        "our",
        "out",
        "outside",
        "over",
        "own",
        "owner",
        "page",
        "painting",
        "paper",
        "parent",
        "part",
        "participant",
        "particular",
        "particularly",
        "partner",
        "party",
        "pass",
        "past",
        "pattern",
        "pay",
        "peace",
        "people",
        "per",
        "perform",
        "performance",
        "perhaps",
        "person",
        "personal",
        "phone",
        "physical",
        "pick",
        "picture",
        "piece",
        "place",
        "plan",
        "plant",
        "play",
        "player",
        "PM",
        "point",
        "police",
        "policy",
        "political",
        "politics",
        "poor",
        "popular",
        "population",
        "position",
        "positive",
        "possible",
        "power",
        "practice",
        "prepare",
        "present",
        "president",
        "pressure",
        "pretty",
        "prevent",
        "price",
        "probably",
        "process",
        "produce",
        "product",
        "production",
        "professional",
        "professor",
        "program",
        "project",
        "property",
        "protect",
        "prove",
        "provide",
        "public",
        "pull",
        "purpose",
        "push",
        "put",
        "quality",
        "question",
        "quickly",
        "quite",
        "race",
        "radio",
        "raise",
        "range",
        "rate",
        "rather",
        "reach",
        "read",
        "ready",
        "real",
        "reality",
        "realize",
        "really",
        "reason",
        "receive",
        "recent",
        "recently",
        "recognize",
        "record",
        "red",
        "reduce",
        "reflect",
        "region",
        "relate",
        "relationship",
        "religious",
        "remain",
        "remember",
        "report",
        "represent",
        "Republican",
        "require",
        "research",
        "resource",
        "respond",
        "response",
        "responsibility",
        "rest",
        "result",
        "return",
        "reveal",
        "rich",
        "right",
        "rise",
        "risk",
        "road",
        "rock",
        "role",
        "room",
        "rule",
        "run",
        "safe",
        "same",
        "save",
        "say",
        "scene",
        "school",
        "science",
        "scientist",
        "score",
        "sea",
        "season",
        "seat",
        "second",
        "section",
        "security",
        "see",
        "seek",
        "seem",
        "sell",
        "send",
        "senior",
        "sense",
        "series",
        "serious",
        "serve",
        "service",
        "set",
        "seven",
        "several",
        "shake",
        "share",
        "she",
        "short",
        "should",
        "shoulder",
        "show",
        "side",
        "sign",
        "significant",
        "similar",
        "simple",
        "simply",
        "since",
        "sing",
        "single",
        "sister",
        "sit",
        "site",
        "situation",
        "six",
        "size",
        "skill",
        "skin",
        "small",
        "smile",
        "so",
        "social",
        "society",
        "soldier",
        "some",
        "somebody",
        "someone",
        "something",
        "sometimes",
        "son",
        "song",
        "soon",
        "sort",
        "sound",
        "source",
        "south",
        "southern",
        "space",
        "speak",
        "special",
        "specific",
        "speech",
        "spend",
        "sport",
        "spring",
        "staff",
        "stage",
        "stand",
        "standard",
        "star",
        "start",
        "state",
        "statement",
        "station",
        "stay",
        "step",
        "still",
        "stock",
        "stop",
        "store",
        "story",
        "strategy",
        "street",
        "strong",
        "structure",
        "student",
        "study",
        "stuff",
        "style",
        "subject",
        "success",
        "successful",
        "such",
        "suddenly",
        "suffer",
        "suggest",
        "summer",
        "support",
        "sure",
        "surface",
        "system",
        "table",
        "take",
        "talk",
        "task",
        "tax",
        "teach",
        "teacher",
        "team",
        "technology",
        "television",
        "tell",
        "ten",
        "tend",
        "term",
        "test",
        "than",
        "thank",
        "that",
        "the",
        "their",
        "them",
        "themselves",
        "then",
        "theory",
        "there",
        "these",
        "they",
        "thing",
        "think",
        "third",
        "this",
        "those",
        "though",
        "thought",
        "thousand",
        "threat",
        "three",
        "through",
        "throughout",
        "throw",
        "thus",
        "time",
        "to",
        "today",
        "together",
        "tonight",
        "too",
        "top",
        "total",
        "tough",
        "toward",
        "town",
        "trade",
        "traditional",
        "training",
        "travel",
        "treat",
        "treatment",
        "tree",
        "trial",
        "trip",
        "trouble",
        "true",
        "truth",
        "try",
        "turn",
        "TV",
        "two",
        "type",
        "under",
        "understand",
        "unit",
        "until",
        "up",
        "upon",
        "us",
        "use",
        "usually",
        "value",
        "various",
        "very",
        "view",
        "visit",
        "voice",
        "vote",
        "wait",
        "walk",
        "wall",
        "want",
        "war",
        "watch",
        "water",
        "way",
        "we",
        "wear",
        "week",
        "weight",
        "well",
        "west",
        "western",
        "what",
        "whatever",
        "when",
        "where",
        "whether",
        "which",
        "while",
        "white",
        "who",
        "whole",
        "whom",
        "whose",
        "why",
        "wide",
        "wife",
        "will",
        "win",
        "wind",
        "window",
        "wish",
        "with",
        "within",
        "without",
        "woman",
        "wonder",
        "word",
        "work",
        "worker",
        "world",
        "worry",
        "would",
        "write",
        "writer",
        "wrong",
        "yard",
        "yeah",
        "year",
        "yes",
        "yet",
        "you",
        "young",
        "your",
        "yourself",
    )

    parts_of_speech: Dict[str, tuple] = {
        "verb": (
            "be",
            "have",
            "do",
            "say",
            "get",
            "make",
            "go",
            "see",
            "know",
            "take",
            "think",
            "come",
            "give",
            "look",
            "use",
            "find",
            "want",
            "tell",
            "put",
            "mean",
            "become",
            "leave",
            "work",
            "need",
            "feel",
            "seem",
            "ask",
            "show",
            "try",
            "call",
            "keep",
            "provide",
            "hold",
            "turn",
            "follow",
            "begin",
            "bring",
            "like",
            "going",
            "help",
            "start",
            "run",
            "write",
            "set",
            "move",
            "play",
            "pay",
            "hear",
            "include",
            "believe",
            "allow",
            "meet",
            "lead",
            "live",
            "stand",
            "happen",
            "carry",
            "talk",
            "appear",
            "produce",
            "sit",
            "offer",
            "consider",
            "expect",
            "let",
            "read",
            "require",
            "continue",
            "lose",
            "add",
            "change",
            "fall",
            "remain",
            "remember",
            "buy",
            "speak",
            "stop",
            "send",
            "receive",
            "decide",
            "win",
            "understand",
            "describe",
            "develop",
            "agree",
            "open",
            "reach",
            "build",
            "involve",
            "spend",
            "return",
            "draw",
            "die",
            "hope",
            "create",
            "walk",
            "sell",
            "wait",
            "cause",
            "pass",
            "lie",
            "accept",
            "watch",
            "raise",
            "base",
            "apply",
            "break",
            "explain",
            "learn",
            "increase",
            "cover",
            "grow",
            "claim",
            "report",
            "support",
            "cut",
            "form",
            "stay",
            "contain",
            "reduce",
            "establish",
            "join",
            "wish",
            "seek",
            "choose",
            "deal",
            "face",
            "fail",
            "serve",
            "end",
            "kill",
            "occur",
            "drive",
            "represent",
            "rise",
            "discuss",
            "love",
            "pick",
            "place",
            "argue",
            "prove",
            "wear",
            "catch",
            "enjoy",
            "eat",
            "introduce",
            "enter",
            "present",
            "arrive",
            "ensure",
            "point",
            "plan",
            "pull",
            "refer",
            "act",
            "relate",
            "affect",
            "close",
            "identify",
            "manage",
            "thank",
            "compare",
            "announce",
            "obtain",
            "note",
            "forget",
            "indicate",
            "wonder",
            "maintain",
            "publish",
            "suffer",
            "avoid",
            "express",
            "suppose",
            "finish",
            "determine",
            "design",
            "listen",
            "save",
            "tend",
            "treat",
            "control",
            "share",
            "remove",
            "throw",
            "visit",
            "exist",
            "force",
            "reflect",
            "admit",
            "assume",
            "smile",
            "prepare",
            "replace",
            "fill",
            "improve",
            "mention",
            "fight",
            "intend",
            "miss",
            "discover",
            "drop",
            "hit",
            "push",
            "prevent",
            "refuse",
            "regard",
            "lay",
            "reveal",
            "teach",
            "answer",
            "operate",
            "state",
            "depend",
            "enable",
            "record",
            "check",
            "complete",
            "cost",
            "sound",
            "laugh",
            "realise",
            "extend",
            "arise",
            "notice",
            "define",
            "examine",
            "fit",
            "study",
            "bear",
            "hang",
            "recognise",
            "shake",
            "sign",
            "attend",
            "fly",
            "gain",
            "result",
            "travel",
            "adopt",
            "confirm",
            "protect",
            "demand",
            "stare",
            "imagine",
            "attempt",
            "beat",
            "born",
            "associate",
            "care",
            "marry",
            "collect",
            "voice",
            "employ",
            "issue",
            "release",
            "emerge",
            "mind",
            "aim",
            "deny",
            "mark",
            "shoot",
            "appoint",
            "order",
            "supply",
            "drink",
            "observe",
            "reply",
            "ignore",
            "link",
            "propose",
            "ring",
            "settle",
            "strike",
            "press",
            "respond",
            "arrange",
            "survive",
            "concentrate",
            "lift",
            "approach",
            "cross",
            "test",
            "charge",
            "experience",
            "touch",
            "acquire",
            "commit",
            "demonstrate",
            "grant",
            "prefer",
            "repeat",
            "sleep",
            "threaten",
            "feed",
            "insist",
            "launch",
            "limit",
            "promote",
            "deliver",
            "measure",
            "own",
            "retain",
            "attract",
            "belong",
            "consist",
            "contribute",
            "hide",
            "promise",
            "reject",
            "cry",
            "impose",
            "invite",
            "sing",
            "vary",
            "warn",
            "address",
            "declare",
            "destroy",
            "worry",
            "divide",
            "head",
            "name",
            "stick",
            "nod",
            "recognize",
            "train",
            "attack",
            "clear",
            "combine",
            "handle",
            "influence",
            "realize",
            "recommend",
            "shout",
            "spread",
            "undertake",
            "account",
            "select",
            "climb",
            "contact",
            "recall",
            "secure",
            "step",
            "transfer",
            "welcome",
            "conclude",
            "disappear",
            "display",
            "dress",
            "illustrate",
            "imply",
            "organise",
            "direct",
            "escape",
            "generate",
            "remind",
            "advise",
            "afford",
            "earn",
            "hand",
            "inform",
            "rely",
            "succeed",
            "approve",
            "burn",
            "fear",
            "vote",
            "conduct",
            "cope",
            "derive",
            "elect",
            "gather",
            "jump",
            "last",
            "match",
            "matter",
            "persuade",
            "ride",
            "shut",
            "blow",
            "estimate",
            "recover",
            "score",
            "slip",
            "count",
            "hate",
            "attach",
            "exercise",
            "house",
            "lean",
            "roll",
            "wash",
            "accuse",
            "bind",
            "judge",
            "rest",
            "steal",
            "comment",
            "exclude",
            "focus",
            "hurt",
            "stretch",
            "withdraw",
            "back",
            "fix",
            "justify",
            "knock",
            "pursue",
            "switch",
            "benefit",
            "lack",
            "list",
            "occupy",
            "permit",
            "surround",
            "abandon",
            "blame",
            "complain",
            "connect",
            "construct",
            "dominate",
            "engage",
            "paint",
            "quote",
            "view",
            "incorporate",
            "interpret",
            "proceed",
            "search",
            "separate",
            "stress",
            "alter",
            "analyse",
            "arrest",
            "bother",
            "defend",
            "expand",
            "implement",
            "possess",
            "review",
            "suit",
            "tie",
            "assist",
            "calculate",
            "glance",
            "mix",
            "question",
            "resolve",
            "rule",
            "suspect",
            "wake",
            "appeal",
            "challenge",
            "clean",
            "damage",
            "guess",
            "reckon",
            "restore",
            "restrict",
            "specify",
            "constitute",
            "convert",
            "distinguish",
            "submit",
            "trust",
            "urge",
            "feature",
            "land",
            "locate",
            "predict",
            "preserve",
            "solve",
            "sort",
            "struggle",
            "cast",
            "cook",
            "dance",
            "invest",
            "lock",
            "owe",
            "pour",
            "shift",
            "kick",
            "kiss",
            "light",
            "purchase",
            "race",
            "retire",
        ),
        "noun": (
            "people",
            "history",
            "way",
            "art",
            "world",
            "information",
            "map",
            "family",
            "government",
            "health",
            "system",
            "computer",
            "meat",
            "year",
            "thanks",
            "music",
            "person",
            "reading",
            "method",
            "data",
            "food",
            "understanding",
            "theory",
            "law",
            "bird",
            "literature",
            "problem",
            "software",
            "control",
            "knowledge",
            "power",
            "ability",
            "economics",
            "love",
            "internet",
            "television",
            "science",
            "library",
            "nature",
            "fact",
            "product",
            "idea",
            "temperature",
            "investment",
            "area",
            "society",
            "activity",
            "story",
            "industry",
            "media",
            "thing",
            "oven",
            "community",
            "definition",
            "safety",
            "quality",
            "development",
            "language",
            "management",
            "player",
            "variety",
            "video",
            "week",
            "security",
            "country",
            "exam",
            "movie",
            "organization",
            "equipment",
            "physics",
            "analysis",
            "policy",
            "series",
            "thought",
            "basis",
            "boyfriend",
            "direction",
            "strategy",
            "technology",
            "army",
            "camera",
            "freedom",
            "paper",
            "environment",
            "child",
            "instance",
            "month",
            "truth",
            "marketing",
            "university",
            "writing",
            "article",
            "department",
            "difference",
            "goal",
            "news",
            "audience",
            "fishing",
            "growth",
            "income",
            "marriage",
            "user",
            "combination",
            "failure",
            "meaning",
            "medicine",
            "philosophy",
            "teacher",
            "communication",
            "night",
            "chemistry",
            "disease",
            "disk",
            "energy",
            "nation",
            "road",
            "role",
            "soup",
            "advertising",
            "location",
            "success",
            "addition",
            "apartment",
            "education",
            "math",
            "moment",
            "painting",
            "politics",
            "attention",
            "decision",
            "event",
            "property",
            "shopping",
            "student",
            "wood",
            "competition",
            "distribution",
            "entertainment",
            "office",
            "population",
            "president",
            "unit",
            "category",
            "cigarette",
            "context",
            "introduction",
            "opportunity",
            "performance",
            "driver",
            "flight",
            "length",
            "magazine",
            "newspaper",
            "relationship",
            "teaching",
            "cell",
            "dealer",
            "finding",
            "lake",
            "member",
            "message",
            "phone",
            "scene",
            "appearance",
            "association",
            "concept",
            "customer",
            "death",
            "discussion",
            "housing",
            "inflation",
            "insurance",
            "mood",
            "woman",
            "advice",
            "blood",
            "effort",
            "expression",
            "importance",
            "opinion",
            "payment",
            "reality",
            "responsibility",
            "situation",
            "skill",
            "statement",
            "wealth",
            "application",
            "city",
            "county",
            "depth",
            "estate",
            "foundation",
            "grandmother",
            "heart",
            "perspective",
            "photo",
            "recipe",
            "studio",
            "topic",
            "collection",
            "depression",
            "imagination",
            "passion",
            "percentage",
            "resource",
            "setting",
            "ad",
            "agency",
            "college",
            "connection",
            "criticism",
            "debt",
            "description",
            "memory",
            "patience",
            "secretary",
            "solution",
            "administration",
            "aspect",
            "attitude",
            "director",
            "personality",
            "psychology",
            "recommendation",
            "response",
            "selection",
            "storage",
            "version",
            "alcohol",
            "argument",
            "complaint",
            "contract",
            "emphasis",
            "highway",
            "loss",
            "membership",
            "possession",
            "preparation",
            "steak",
            "union",
            "agreement",
            "cancer",
            "currency",
            "employment",
            "engineering",
            "entry",
            "interaction",
            "mixture",
            "preference",
            "region",
            "republic",
            "tradition",
            "virus",
            "actor",
            "classroom",
            "delivery",
            "device",
            "difficulty",
            "drama",
            "election",
            "engine",
            "football",
            "guidance",
            "hotel",
            "owner",
            "priority",
            "protection",
            "suggestion",
            "tension",
            "variation",
            "anxiety",
            "atmosphere",
            "awareness",
            "bath",
            "bread",
            "candidate",
            "climate",
            "comparison",
            "confusion",
            "construction",
            "elevator",
            "emotion",
            "employee",
            "employer",
            "guest",
            "height",
            "leadership",
            "mall",
            "manager",
            "operation",
            "recording",
            "sample",
            "transportation",
            "charity",
            "cousin",
            "disaster",
            "editor",
            "efficiency",
            "excitement",
            "extent",
            "feedback",
            "guitar",
            "homework",
            "leader",
            "mom",
            "outcome",
            "permission",
            "presentation",
            "promotion",
            "reflection",
            "refrigerator",
            "resolution",
            "revenue",
            "session",
            "singer",
            "tennis",
            "basket",
            "bonus",
            "cabinet",
            "childhood",
            "church",
            "clothes",
            "coffee",
            "dinner",
            "drawing",
            "hair",
            "hearing",
            "initiative",
            "judgment",
            "lab",
            "measurement",
            "mode",
            "mud",
            "orange",
            "poetry",
            "police",
            "possibility",
            "procedure",
            "queen",
            "ratio",
            "relation",
            "restaurant",
            "satisfaction",
            "sector",
            "signature",
            "significance",
            "song",
            "tooth",
            "town",
            "vehicle",
            "volume",
            "wife",
            "accident",
            "airport",
            "appointment",
            "arrival",
            "assumption",
            "baseball",
            "chapter",
            "committee",
            "conversation",
            "database",
            "enthusiasm",
            "error",
            "explanation",
            "farmer",
            "gate",
            "girl",
            "hall",
            "historian",
            "hospital",
            "injury",
            "instruction",
            "maintenance",
            "manufacturer",
            "meal",
            "perception",
            "pie",
            "poem",
            "presence",
            "proposal",
            "reception",
            "replacement",
            "revolution",
            "river",
            "son",
            "speech",
            "tea",
            "village",
            "warning",
            "winner",
            "worker",
            "writer",
            "assistance",
            "breath",
            "buyer",
            "chest",
            "chocolate",
            "conclusion",
            "contribution",
            "cookie",
            "courage",
            "desk",
            "drawer",
            "establishment",
            "examination",
            "garbage",
            "grocery",
            "honey",
            "impression",
            "improvement",
            "independence",
            "insect",
            "inspection",
            "inspector",
            "king",
            "ladder",
            "menu",
            "penalty",
            "piano",
            "potato",
            "profession",
            "professor",
            "quantity",
            "reaction",
            "requirement",
            "salad",
            "sister",
            "supermarket",
            "tongue",
            "weakness",
            "wedding",
            "affair",
            "ambition",
            "analyst",
            "apple",
            "assignment",
            "assistant",
            "bathroom",
            "bedroom",
            "beer",
            "birthday",
            "celebration",
            "championship",
            "cheek",
            "client",
            "consequence",
            "departure",
            "diamond",
            "dirt",
            "ear",
            "fortune",
            "friendship",
            "funeral",
            "gene",
            "girlfriend",
            "hat",
            "indication",
            "intention",
            "lady",
            "midnight",
            "negotiation",
            "obligation",
            "passenger",
            "pizza",
            "platform",
            "poet",
            "pollution",
            "recognition",
            "reputation",
            "shirt",
            "sir",
            "speaker",
            "stranger",
            "surgery",
            "sympathy",
            "tale",
            "throat",
            "trainer",
            "uncle",
            "youth",
            "time",
            "work",
            "film",
            "water",
            "money",
            "example",
            "while",
            "business",
            "study",
            "game",
            "life",
            "form",
            "air",
            "day",
            "place",
            "number",
            "part",
            "field",
            "fish",
            "back",
            "process",
            "heat",
            "hand",
            "experience",
            "job",
            "book",
            "end",
            "point",
            "type",
            "home",
            "economy",
            "value",
            "body",
            "market",
            "guide",
            "interest",
            "state",
            "radio",
            "course",
            "company",
            "price",
            "size",
            "card",
            "list",
            "mind",
            "trade",
            "line",
            "care",
            "group",
            "risk",
            "word",
            "fat",
            "force",
            "key",
            "light",
            "training",
            "name",
            "school",
            "top",
            "amount",
            "level",
            "order",
            "practice",
            "research",
            "sense",
            "service",
            "piece",
            "web",
            "boss",
            "sport",
            "fun",
            "house",
            "page",
            "term",
            "test",
            "answer",
            "sound",
            "focus",
            "matter",
            "kind",
            "soil",
            "board",
            "oil",
            "picture",
            "access",
            "garden",
            "range",
            "rate",
            "reason",
            "future",
            "site",
            "demand",
            "exercise",
            "image",
            "case",
            "cause",
            "coast",
            "action",
            "age",
            "bad",
            "boat",
            "record",
            "result",
            "section",
            "building",
            "mouse",
            "cash",
            "class",
            "nothing",
            "period",
            "plan",
            "store",
            "tax",
            "side",
            "subject",
            "space",
            "rule",
            "stock",
            "weather",
            "chance",
            "figure",
            "man",
            "model",
            "source",
            "beginning",
            "earth",
            "program",
            "chicken",
            "design",
            "feature",
            "head",
            "material",
            "purpose",
            "question",
            "rock",
            "salt",
            "act",
            "birth",
            "car",
            "dog",
            "object",
            "scale",
            "sun",
            "note",
            "profit",
            "rent",
            "speed",
            "style",
            "war",
            "bank",
            "craft",
            "half",
            "inside",
            "outside",
            "standard",
            "bus",
            "exchange",
            "eye",
            "fire",
            "position",
            "pressure",
            "stress",
            "advantage",
            "benefit",
            "box",
            "frame",
            "issue",
            "step",
            "cycle",
            "face",
            "item",
            "metal",
            "paint",
            "review",
            "room",
            "screen",
            "structure",
            "view",
            "account",
            "ball",
            "discipline",
            "medium",
            "share",
            "balance",
            "bit",
            "black",
            "bottom",
            "choice",
            "gift",
            "impact",
            "machine",
            "shape",
            "tool",
            "wind",
            "address",
            "average",
            "career",
            "culture",
            "morning",
            "pot",
            "sign",
            "table",
            "task",
            "condition",
            "contact",
            "credit",
            "egg",
            "hope",
            "ice",
            "network",
            "north",
            "square",
            "attempt",
            "date",
            "effect",
            "link",
            "post",
            "star",
            "voice",
            "capital",
            "challenge",
            "friend",
            "self",
            "shot",
            "brush",
            "couple",
            "debate",
            "exit",
            "front",
            "function",
            "lack",
            "living",
            "plant",
            "plastic",
            "spot",
            "summer",
            "taste",
            "theme",
            "track",
            "wing",
            "brain",
            "button",
            "click",
            "desire",
            "foot",
            "gas",
            "influence",
            "notice",
            "rain",
            "wall",
            "base",
            "damage",
            "distance",
            "feeling",
            "pair",
            "savings",
            "staff",
            "sugar",
            "target",
            "text",
            "animal",
            "author",
            "budget",
            "discount",
            "file",
            "ground",
            "lesson",
            "minute",
            "officer",
            "phase",
            "reference",
            "register",
            "sky",
            "stage",
            "stick",
            "title",
            "trouble",
            "bowl",
            "bridge",
            "campaign",
            "character",
            "club",
            "edge",
            "evidence",
            "fan",
            "letter",
            "lock",
            "maximum",
            "novel",
            "option",
            "pack",
            "park",
            "plenty",
            "quarter",
            "skin",
            "sort",
            "weight",
            "baby",
            "background",
            "carry",
            "dish",
            "factor",
            "fruit",
            "glass",
            "joint",
            "master",
            "muscle",
            "red",
            "strength",
            "traffic",
            "trip",
            "vegetable",
            "appeal",
            "chart",
            "gear",
            "ideal",
            "kitchen",
            "land",
            "log",
            "mother",
            "net",
            "party",
            "principle",
            "relative",
            "sale",
            "season",
            "signal",
            "spirit",
            "street",
            "tree",
            "wave",
            "belt",
            "bench",
            "commission",
            "copy",
            "drop",
            "minimum",
            "path",
            "progress",
            "project",
            "sea",
            "south",
            "status",
            "stuff",
            "ticket",
            "tour",
            "angle",
            "blue",
            "breakfast",
            "confidence",
            "daughter",
            "degree",
            "doctor",
            "dot",
            "dream",
            "duty",
            "essay",
            "father",
            "fee",
            "finance",
            "hour",
            "juice",
            "limit",
            "luck",
            "milk",
            "mouth",
            "peace",
            "pipe",
            "seat",
            "stable",
            "storm",
            "substance",
            "team",
            "trick",
            "afternoon",
            "bat",
            "beach",
            "blank",
            "catch",
            "chain",
            "consideration",
            "cream",
            "crew",
            "detail",
            "gold",
            "interview",
            "kid",
            "mark",
            "match",
            "mission",
            "pain",
            "pleasure",
            "score",
            "screw",
            "sex",
            "shop",
            "shower",
            "suit",
            "tone",
            "window",
            "agent",
            "band",
            "block",
            "bone",
            "calendar",
            "cap",
            "coat",
            "contest",
            "corner",
            "court",
            "cup",
            "district",
            "door",
            "east",
            "finger",
            "garage",
            "guarantee",
            "hole",
            "hook",
            "implement",
            "layer",
            "lecture",
            "lie",
            "manner",
            "meeting",
            "nose",
            "parking",
            "partner",
            "profile",
            "respect",
            "rice",
            "routine",
            "schedule",
            "swimming",
            "telephone",
            "tip",
            "winter",
            "airline",
            "bag",
            "battle",
            "bed",
            "bill",
            "bother",
            "cake",
            "code",
            "curve",
            "designer",
            "dimension",
            "dress",
            "ease",
            "emergency",
            "evening",
            "extension",
            "farm",
            "fight",
            "gap",
            "grade",
            "holiday",
            "horror",
            "horse",
            "host",
            "husband",
            "loan",
            "mistake",
            "mountain",
            "nail",
            "noise",
            "occasion",
            "package",
            "patient",
            "pause",
            "phrase",
            "proof",
            "race",
            "relief",
            "sand",
            "sentence",
            "shoulder",
            "smoke",
            "stomach",
            "string",
            "tourist",
            "towel",
            "vacation",
            "west",
            "wheel",
            "wine",
            "arm",
            "aside",
            "associate",
            "bet",
            "blow",
            "border",
            "branch",
            "breast",
            "brother",
            "buddy",
            "bunch",
            "chip",
            "coach",
            "cross",
            "document",
            "draft",
            "dust",
            "expert",
            "floor",
            "god",
            "golf",
            "habit",
            "iron",
            "judge",
            "knife",
            "landscape",
            "league",
            "mail",
            "mess",
            "native",
            "opening",
            "parent",
            "pattern",
            "pin",
            "pool",
            "pound",
            "request",
            "salary",
            "shame",
            "shelter",
            "shoe",
            "silver",
            "tackle",
            "tank",
            "trust",
            "assist",
            "bake",
            "bar",
            "bell",
            "bike",
            "blame",
            "boy",
            "brick",
            "chair",
            "closet",
            "clue",
            "collar",
            "comment",
            "conference",
            "devil",
            "diet",
            "fear",
            "fuel",
            "glove",
            "jacket",
            "lunch",
            "monitor",
            "mortgage",
            "nurse",
            "pace",
            "panic",
            "peak",
            "plane",
            "reward",
            "row",
            "sandwich",
            "shock",
            "spite",
            "spray",
            "surprise",
            "till",
            "transition",
            "weekend",
            "welcome",
            "yard",
            "alarm",
            "bend",
            "bicycle",
            "bite",
            "blind",
            "bottle",
            "cable",
            "candle",
            "clerk",
            "cloud",
            "concert",
            "counter",
            "flower",
            "grandfather",
            "harm",
            "knee",
            "lawyer",
            "leather",
            "load",
            "mirror",
            "neck",
            "pension",
            "plate",
            "purple",
            "ruin",
            "ship",
            "skirt",
            "slice",
            "snow",
            "specialist",
            "stroke",
            "switch",
            "trash",
            "tune",
            "zone",
            "anger",
            "award",
            "bid",
            "bitter",
            "boot",
            "bug",
            "camp",
            "candy",
            "carpet",
            "cat",
            "champion",
            "channel",
            "clock",
            "comfort",
            "cow",
            "crack",
            "engineer",
            "entrance",
            "fault",
            "grass",
            "guy",
            "hell",
            "highlight",
            "incident",
            "island",
            "joke",
            "jury",
            "leg",
            "lip",
            "mate",
            "motor",
            "nerve",
            "passage",
            "pen",
            "pride",
            "priest",
            "prize",
            "promise",
            "resident",
            "resort",
            "ring",
            "roof",
            "rope",
            "sail",
            "scheme",
            "script",
            "sock",
            "station",
            "toe",
            "tower",
            "truck",
            "witness",
        ),
        "adverb": (
            "not",
            "also",
            "very",
            "often",
            "however",
            "too",
            "usually",
            "really",
            "early",
            "never",
            "always",
            "sometimes",
            "together",
            "likely",
            "simply",
            "generally",
            "instead",
            "actually",
            "again",
            "rather",
            "almost",
            "especially",
            "ever",
            "quickly",
            "probably",
            "already",
            "below",
            "directly",
            "therefore",
            "else",
            "thus",
            "easily",
            "eventually",
            "exactly",
            "certainly",
            "normally",
            "currently",
            "extremely",
            "finally",
            "constantly",
            "properly",
            "soon",
            "specifically",
            "ahead",
            "daily",
            "highly",
            "immediately",
            "relatively",
            "slowly",
            "fairly",
            "primarily",
            "completely",
            "ultimately",
            "widely",
            "recently",
            "seriously",
            "frequently",
            "fully",
            "mostly",
            "naturally",
            "nearly",
            "occasionally",
            "carefully",
            "clearly",
            "essentially",
            "possibly",
            "slightly",
            "somewhat",
            "equally",
            "greatly",
            "necessarily",
            "personally",
            "rarely",
            "regularly",
            "similarly",
            "basically",
            "closely",
            "effectively",
            "initially",
            "literally",
            "mainly",
            "merely",
            "gently",
            "hopefully",
            "originally",
            "roughly",
            "significantly",
            "totally",
            "twice",
            "elsewhere",
            "everywhere",
            "obviously",
            "perfectly",
            "physically",
            "successfully",
            "suddenly",
            "truly",
            "virtually",
            "altogether",
            "anyway",
            "automatically",
            "deeply",
            "definitely",
            "deliberately",
            "hardly",
            "readily",
            "terribly",
            "unfortunately",
            "forth",
            "briefly",
            "moreover",
            "strongly",
            "honestly",
            "previously",
            "as",
            "there",
            "when",
            "how",
            "so",
            "up",
            "out",
            "only",
            "well",
            "then",
            "first",
            "where",
            "why",
            "now",
            "around",
            "once",
            "down",
            "off",
            "here",
            "tonight",
            "away",
            "today",
            "far",
            "quite",
            "later",
            "above",
            "yet",
            "maybe",
            "otherwise",
            "near",
            "forward",
            "somewhere",
            "anywhere",
            "please",
            "forever",
            "somehow",
            "absolutely",
            "abroad",
            "yeah",
            "nowhere",
            "tomorrow",
            "yesterday",
        ),
        "adjective": (
            "different",
            "used",
            "important",
            "every",
            "large",
            "available",
            "popular",
            "able",
            "basic",
            "known",
            "various",
            "difficult",
            "several",
            "united",
            "historical",
            "hot",
            "useful",
            "mental",
            "scared",
            "additional",
            "emotional",
            "old",
            "political",
            "similar",
            "healthy",
            "financial",
            "medical",
            "traditional",
            "federal",
            "entire",
            "strong",
            "actual",
            "significant",
            "successful",
            "electrical",
            "expensive",
            "pregnant",
            "intelligent",
            "interesting",
            "poor",
            "happy",
            "responsible",
            "cute",
            "helpful",
            "recent",
            "willing",
            "nice",
            "wonderful",
            "impossible",
            "serious",
            "huge",
            "rare",
            "technical",
            "typical",
            "competitive",
            "critical",
            "electronic",
            "immediate",
            "aware",
            "educational",
            "environmental",
            "global",
            "legal",
            "relevant",
            "accurate",
            "capable",
            "dangerous",
            "dramatic",
            "efficient",
            "powerful",
            "foreign",
            "hungry",
            "practical",
            "psychological",
            "severe",
            "suitable",
            "numerous",
            "sufficient",
            "unusual",
            "consistent",
            "cultural",
            "existing",
            "famous",
            "pure",
            "afraid",
            "obvious",
            "careful",
            "latter",
            "unhappy",
            "acceptable",
            "aggressive",
            "boring",
            "distinct",
            "eastern",
            "logical",
            "reasonable",
            "strict",
            "administrative",
            "automatic",
            "civil",
            "former",
            "massive",
            "southern",
            "unfair",
            "visible",
            "alive",
            "angry",
            "desperate",
            "exciting",
            "friendly",
            "lucky",
            "realistic",
            "sorry",
            "ugly",
            "unlikely",
            "anxious",
            "comprehensive",
            "curious",
            "impressive",
            "informal",
            "inner",
            "pleasant",
            "sexual",
            "sudden",
            "terrible",
            "unable",
            "weak",
            "wooden",
            "asleep",
            "confident",
            "conscious",
            "decent",
            "embarrassed",
            "guilty",
            "lonely",
            "mad",
            "nervous",
            "odd",
            "remarkable",
            "substantial",
            "suspicious",
            "tall",
            "tiny",
            "more",
            "some",
            "all",
            "many",
            "most",
            "other",
            "such",
            "even",
            "new",
            "just",
            "good",
            "any",
            "each",
            "much",
            "own",
            "great",
            "another",
            "same",
            "few",
            "free",
            "right",
            "still",
            "best",
            "public",
            "human",
            "both",
            "local",
            "sure",
            "better",
            "general",
            "specific",
            "enough",
            "long",
            "small",
            "less",
            "high",
            "certain",
            "little",
            "common",
            "next",
            "simple",
            "hard",
            "past",
            "big",
            "possible",
            "particular",
            "real",
            "major",
            "personal",
            "current",
            "left",
            "national",
            "least",
            "natural",
            "physical",
            "short",
            "last",
            "single",
            "individual",
            "main",
            "potential",
            "professional",
            "international",
            "lower",
            "open",
            "according",
            "alternative",
            "special",
            "working",
            "true",
            "whole",
            "clear",
            "dry",
            "easy",
            "cold",
            "commercial",
            "full",
            "low",
            "primary",
            "worth",
            "necessary",
            "positive",
            "present",
            "close",
            "creative",
            "green",
            "late",
            "fit",
            "glad",
            "proper",
            "complex",
            "content",
            "due",
            "effective",
            "middle",
            "regular",
            "fast",
            "independent",
            "original",
            "wide",
            "beautiful",
            "complete",
            "active",
            "negative",
            "safe",
            "visual",
            "wrong",
            "ago",
            "quick",
            "ready",
            "straight",
            "white",
            "direct",
            "excellent",
            "extra",
            "junior",
            "pretty",
            "unique",
            "classic",
            "final",
            "overall",
            "private",
            "separate",
            "western",
            "alone",
            "familiar",
            "official",
            "perfect",
            "bright",
            "broad",
            "comfortable",
            "flat",
            "rich",
            "warm",
            "young",
            "heavy",
            "valuable",
            "correct",
            "leading",
            "slow",
            "clean",
            "fresh",
            "normal",
            "secret",
            "tough",
            "brown",
            "cheap",
            "deep",
            "objective",
            "secure",
            "thin",
            "chemical",
            "cool",
            "extreme",
            "exact",
            "fair",
            "fine",
            "formal",
            "opposite",
            "remote",
            "total",
            "vast",
            "lost",
            "smooth",
            "dark",
            "double",
            "equal",
            "firm",
            "frequent",
            "internal",
            "sensitive",
            "constant",
            "minor",
            "previous",
            "raw",
            "soft",
            "solid",
            "weird",
            "amazing",
            "annual",
            "busy",
            "dead",
            "false",
            "round",
            "sharp",
            "thick",
            "wise",
            "equivalent",
            "initial",
            "narrow",
            "nearby",
            "proud",
            "spiritual",
            "wild",
            "adult",
            "apart",
            "brief",
            "crazy",
            "prior",
            "rough",
            "sad",
            "sick",
            "strange",
            "external",
            "illegal",
            "loud",
            "mobile",
            "nasty",
            "ordinary",
            "royal",
            "senior",
            "super",
            "tight",
            "upper",
            "yellow",
            "dependent",
            "funny",
            "gross",
            "ill",
            "spare",
            "sweet",
            "upstairs",
            "usual",
            "brave",
            "calm",
            "dirty",
            "downtown",
            "grand",
            "honest",
            "loose",
            "male",
            "quiet",
            "brilliant",
            "dear",
            "drunk",
            "empty",
            "female",
            "inevitable",
            "neat",
            "ok",
            "representative",
            "silly",
            "slight",
            "smart",
            "stupid",
            "temporary",
            "weekly",
        ),
    }



from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    # Source: https://en.wikipedia.org/wiki/Telephone_numbers_in_Algeria

    cellphone_formats = (
        "0{{mobile_operator}}## ## ## ##",
        "+213 {{mobile_operator}}## ## ## ##",
    )

    telephone_formats = (
        "0{{area_code}} ## ## ##",
        "+213 {{area_code}} ## ## ##",
    )

    formats = cellphone_formats + telephone_formats

    def mobile_operator(self) -> str:
        return self.random_element(["5", "6", "7"])

    def area_code(self) -> str:
        return self.random_element(
            [
                "21",
                "23",
                "24",
                "25",
                "26",
                "27",
                "29",
                "31",
                "32",
                "33",
                "34",
                "35",
                "36",
                "37",
                "38",
                "39",
                "41",
                "43",
                "45",
                "46",
                "48",
                "49",
            ]
        )

    def cellphone_number(self) -> str:
        pattern: str = self.random_element(self.cellphone_formats)
        return self.numerify(self.generator.parse(pattern))

    def telephone_number(self) -> str:
        pattern: str = self.random_element(self.telephone_formats)
        return self.numerify(self.generator.parse(pattern))

    def phone_number(self) -> str:
        pattern: str = self.random_element(self.formats)
        return self.numerify(self.generator.parse(pattern))



from .. import Provider as BaseProvider


class Provider(BaseProvider):

    # Sources:
    #   - https://www.ons.dz/IMG/file/Profession.pdf
    jobs_male = (
        "accompagnateur de tourisme",
        "acheteur",
        "adjoint administratif",
        "agent commercial",
        "agent de sécurité",
        "agent des douanes",
        "agent des impôts",
        "analyste financier",
        "architecte",
        "archiviste",
        "assistant de direction",
        "assistant social",
        "attaché de presse",
        "auditeur",
        "avocat",
        "biologiste",
        "cadre administratif",
        "cadre bancaire",
        "cadre commercial",
        "cadre de la fonction publique",
        "chargé d'études",
        "chargé de communication",
        "chargé de projet",
        "chauffeur",
        "chef de chantier",
        "chef de projet informatique",
        "chef de service",
        "chirurgien",
        "commis de cuisine",
        "comptable",
        "conducteur de travaux",
        "conseiller juridique",
        "contrôleur de gestion",
        "déclarant en douane",
        "dentiste",
        "dessinateur industriel",
        "développeur informatique",
        "directeur commercial",
        "directeur des ressources humaines",
        "directeur financier",
        "directeur général",
        "directeur technique",
        "économiste",
        "électricien de bâtiment",
        "employé administratif",
        "employé de banque",
        "enseignant du primaire",
        "enseignant du secondaire",
        "enseignant-chercheur",
        "expert judiciaire",
        "expert-comptable",
        "fonctionnaire",
        "formateur professionnel",
        "géologue",
        "géomètre-topographe",
        "gestionnaire de paie",
        "guide touristique",
        "huissier de justice",
        "hydraulicien",
        "infirmier",
        "ingénieur chimiste",
        "ingénieur civil",
        "ingénieur d'état",
        "ingénieur électricien",
        "ingénieur électronicien",
        "ingénieur en génie civil",
        "ingénieur en informatique",
        "ingénieur en télécommunications",
        "ingénieur géologue",
        "ingénieur mécanicien",
        "ingénieur pétrolier",
        "inspecteur de l'éducation",
        "inspecteur des impôts",
        "interprète",
        "journaliste",
        "juge",
        "juriste",
        "kinésithérapeute",
        "laborantin",
        "logisticien",
        "magistrat",
        "maître assistant",
        "maître de conférences",
        "maïeuticien",
        "médecin généraliste",
        "médecin spécialiste",
        "médecin vétérinaire",
        "menuisier",
        "notaire",
        "officier de police judiciaire",
        "opérateur de forage",
        "pharmacien",
        "plombier",
        "pompier",
        "procureur de la République",
        "professeur de lycée",
        "professeur de l'enseignement supérieur",
        "psychologue",
        "rédacteur",
        "représentant commercial",
        "responsable informatique",
        "responsable qualité",
        "secrétaire",
        "soudeur",
        "surveillant général",
        "technicien de laboratoire",
        "technicien en électricité",
        "technicien en informatique",
        "technicien en télécommunications",
        "technicien supérieur",
        "topographe",
        "traducteur",
        "travailleur social",
    )

    jobs_female = (
        "accompagnatrice de tourisme",
        "acheteuse",
        "adjointe administrative",
        "agente commerciale",
        "agente de sécurité",
        "agente des douanes",
        "agente des impôts",
        "analyste financière",
        "architecte",
        "archiviste",
        "assistante de direction",
        "assistante sociale",
        "attachée de presse",
        "auditrice",
        "avocate",
        "biologiste",
        "cadre administrative",
        "cadre bancaire",
        "cadre commerciale",
        "cadre de la fonction publique",
        "chargée d'études",
        "chargée de communication",
        "chargée de projet",
        "chauffeuse",
        "cheffe de chantier",
        "cheffe de projet informatique",
        "cheffe de service",
        "chirurgienne",
        "commise de cuisine",
        "comptable",
        "conductrice de travaux",
        "conseillère juridique",
        "contrôleuse de gestion",
        "déclarante en douane",
        "dentiste",
        "dessinatrice industrielle",
        "développeuse informatique",
        "directrice commerciale",
        "directrice des ressources humaines",
        "directrice financière",
        "directrice générale",
        "directrice technique",
        "économiste",
        "électricienne de bâtiment",
        "employée administrative",
        "employée de banque",
        "enseignante du primaire",
        "enseignante du secondaire",
        "enseignante-chercheuse",
        "experte judiciaire",
        "experte-comptable",
        "fonctionnaire",
        "formatrice professionnelle",
        "géologue",
        "géomètre-topographe",
        "gestionnaire de paie",
        "guide touristique",
        "huissière de justice",
        "hydraulicienne",
        "infirmière",
        "ingénieure chimiste",
        "ingénieure civile",
        "ingénieure d'état",
        "ingénieure électricienne",
        "ingénieure électronicienne",
        "ingénieure en génie civil",
        "ingénieure en informatique",
        "ingénieure en télécommunications",
        "ingénieure géologue",
        "ingénieure mécanicienne",
        "ingénieure pétrolière",
        "inspectrice de l'éducation",
        "inspectrice des impôts",
        "interprète",
        "journaliste",
        "juge",
        "juriste",
        "kinésithérapeute",
        "laborantine",
        "logisticienne",
        "magistrate",
        "maître assistante",
        "maître de conférences",
        "sage-femme",
        "médecin généraliste",
        "médecin spécialiste",
        "médecin vétérinaire",
        "menuisière",
        "notaire",
        "officière de police judiciaire",
        "opératrice de forage",
        "pharmacienne",
        "plombière",
        "pompière",
        "procureure de la République",
        "professeure de lycée",
        "professeure de l'enseignement supérieur",
        "psychologue",
        "rédactrice",
        "représentante commerciale",
        "responsable informatique",
        "responsable qualité",
        "secrétaire",
        "soudeuse",
        "surveillante générale",
        "technicienne de laboratoire",
        "technicienne en électricité",
        "technicienne en informatique",
        "technicienne en télécommunications",
        "technicienne supérieure",
        "topographe",
        "traductrice",
        "travailleuse sociale",
    )

    jobs = jobs_male + jobs_female



from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    # Source references (accessed 2026-04-18):
    # - https://dot.gov.in/numbering-resources (India numbering resources)
    # - Faker locale patterns in `phone_number/hi_IN` and `phone_number/ta_IN`
    # Patterns are intended for structurally valid synthetic Indian numbers.
    formats = (
        "+91 ##########",
        "+91 ### #######",
        "0##-########",
        "0##########",
        "0#### ######",
    )



from collections import OrderedDict
from typing import Dict, Tuple

from ... import ElementsType
from ..es import Provider as AddressProvider


class Provider(AddressProvider):
    # Source for regions, provinces and communes
    # https://www.subdere.gov.cl/documentacion/c%C3%B3digos-%C3%BAnicos-
    # territoriales-actualizados-al-06-de-septiembre-2018
    regions: Dict[str, str] = {
        "TA": "Región de Tarapacá",
        "AN": "Región de Antofagasta",
        "AT": "Región de Atacama",
        "CO": "Región de Coquimbo",
        "VA": "Región de Valparaíso",
        "LI": "Región del Libertador General Bernardo O'Higgins",
        "ML": "Región del Maule",
        "BI": "Región del Biobío",
        "AR": "Región de La Araucanía",
        "LL": "Región de Los Lagos",
        "AI": "Región de Aysén del General Carlos Ibáñez del Campo",
        "MA": "Región de Magallanes y de la Antártica Chilena",
        "RM": "Región Metropolitana",
        "LR": "Región de Los Ríos",
        "AP": "Región de Arica y Parinacota",
        "NB": "Región de Ñuble",
    }

    provinces: Dict[str, str] = {
        "011": "Iquique",
        "014": "Tamarugal",
        "021": "Antofagasta",
        "022": "El Loa",
        "023": "Tocopilla",
        "031": "Copiapó",
        "032": "Chañaral",
        "033": "Huasco",
        "041": "Elqui",
        "042": "Choapa",
        "043": "Limarí",
        "051": "Valparaíso",
        "052": "Isla de Pascua",
        "053": "Los Andes",
        "054": "Petorca",
        "055": "Quillota",
        "056": "San Antonio",
        "057": "San Felipe de Aconcagua",
        "058": "Marga Marga",
        "061": "Cachapoal",
        "062": "Cardenal Caro",
        "063": "Colchagua",
        "071": "Talca",
        "072": "Cauquenes",
        "073": "Curicó",
        "074": "Linares",
        "081": "Concepción",
        "082": "Arauco",
        "083": "Biobío",
        "091": "Cautín",
        "092": "Malleco",
        "101": "Llanquihue",
        "102": "Chiloé",
        "103": "Osorno",
        "104": "Palena",
        "111": "Coyhaique",
        "112": "Aysén",
        "113": "Capitán Prat",
        "114": "General Carrera",
        "121": "Magallanes",
        "122": "Antártica Chilena",
        "123": "Tierra del Fuego",
        "124": "Última Esperanza",
        "131": "Santiago",
        "132": "Cordillera",
        "133": "Chacabuco",
        "134": "Maipo",
        "135": "Melipilla",
        "136": "Talagante",
        "141": "Valdivia",
        "142": "Ranco",
        "151": "Arica",
        "152": "Parinacota",
        "161": "Diguillín",
        "162": "Itata",
        "163": "Punilla",
    }

    communes: Dict[str, str] = {
        "15101": "Arica",
        "15102": "Camarones",
        "15201": "Putre",
        "15202": "General Lagos",
        "01101": "Iquique",
        "01402": "Camiña",
        "01403": "Colchane",
        "01404": "Huara",
        "01405": "Pica",
        "01401": "Pozo Almonte",
        "01107": "Alto Hospicio",
        "02101": "Antofagasta",
        "02102": "Mejillones",
        "02103": "Sierra Gorda",
        "02104": "Taltal",
        "02201": "Calama",
        "02202": "Ollagüe",
        "02203": "San Pedro de Atacama",
        "02301": "Tocopilla",
        "02302": "María Elena",
        "03101": "Copiapó",
        "03102": "Caldera",
        "03103": "Tierra Amarilla",
        "03201": "Chañaral",
        "03202": "Diego de Almagro",
        "03301": "Vallenar",
        "03302": "Alto del Carmen",
        "03303": "Freirina",
        "03304": "Huasco",
        "04101": "La Serena",
        "04102": "Coquimbo",
        "04103": "Andacollo",
        "04104": "La Higuera",
        "04105": "Paiguano",
        "04106": "Vicuña",
        "04201": "Illapel",
        "04202": "Canela",
        "04203": "Los Vilos",
        "04204": "Salamanca",
        "04301": "Ovalle",
        "04302": "Combarbalá",
        "04303": "Monte Patria",
        "04304": "Punitaqui",
        "04305": "Río Hurtado",
        "05101": "Valparaíso",
        "05102": "Casablanca",
        "05103": "Concón",
        "05104": "Juan Fernández",
        "05105": "Puchuncaví",
        "05801": "Quilpué",
        "05107": "Quintero",
        "05804": "Villa Alemana",
        "05109": "Viña del Mar",
        "05201": "Isla  de Pascua",
        "05301": "Los Andes",
        "05302": "Calle Larga",
        "05303": "Rinconada",
        "05304": "San Esteban",
        "05401": "La Ligua",
        "05402": "Cabildo",
        "05403": "Papudo",
        "05404": "Petorca",
        "05405": "Zapallar",
        "05501": "Quillota",
        "05502": "Calera",
        "05503": "Hijuelas",
        "05504": "La Cruz",
        "05802": "Limache",
        "05506": "Nogales",
        "05803": "Olmué",
        "05601": "San Antonio",
        "05602": "Algarrobo",
        "05603": "Cartagena",
        "05604": "El Quisco",
        "05605": "El Tabo",
        "05606": "Santo Domingo",
        "05701": "San Felipe",
        "05702": "Catemu",
        "05703": "Llaillay",
        "05704": "Panquehue",
        "05705": "Putaendo",
        "05706": "Santa María",
        "06101": "Rancagua",
        "06102": "Codegua",
        "06103": "Coinco",
        "06104": "Coltauco",
        "06105": "Doñihue",
        "06106": "Graneros",
        "06107": "Las Cabras",
        "06108": "Machalí",
        "06109": "Malloa",
        "06110": "Mostazal",
        "06111": "Olivar",
        "06112": "Peumo",
        "06113": "Pichidegua",
        "06114": "Quinta de Tilcoco",
        "06115": "Rengo",
        "06116": "Requínoa",
        "06117": "San Vicente",
        "06201": "Pichilemu",
        "06202": "La Estrella",
        "06203": "Litueche",
        "06204": "Marchihue",
        "06205": "Navidad",
        "06206": "Paredones",
        "06301": "San Fernando",
        "06302": "Chépica",
        "06303": "Chimbarongo",
        "06304": "Lolol",
        "06305": "Nancagua",
        "06306": "Palmilla",
        "06307": "Peralillo",
        "06308": "Placilla",
        "06309": "Pumanque",
        "06310": "Santa Cruz",
        "07101": "Talca",
        "07102": "Constitución",
        "07103": "Curepto",
        "07104": "Empedrado",
        "07105": "Maule",
        "07106": "Pelarco",
        "07107": "Pencahue",
        "07108": "Río Claro",
        "07109": "San Clemente",
        "07110": "San Rafael",
        "07201": "Cauquenes",
        "07202": "Chanco",
        "07203": "Pelluhue",
        "07301": "Curicó",
        "07302": "Hualañé",
        "07303": "Licantén",
        "07304": "Molina",
        "07305": "Rauco",
        "07306": "Romeral",
        "07307": "Sagrada Familia",
        "07308": "Teno",
        "07309": "Vichuquén",
        "07401": "Linares",
        "07402": "Colbún",
        "07403": "Longaví",
        "07404": "Parral",
        "07405": "Retiro",
        "07406": "San Javier",
        "07407": "Villa Alegre",
        "07408": "Yerbas Buenas",
        "08101": "Concepción",
        "08102": "Coronel",
        "08103": "Chiguayante",
        "08104": "Florida",
        "08105": "Hualqui",
        "08106": "Lota",
        "08107": "Penco",
        "08108": "San Pedro de la Paz",
        "08109": "Santa Juana",
        "08110": "Talcahuano",
        "08111": "Tomé",
        "08112": "Hualpén",
        "08201": "Lebu",
        "08202": "Arauco",
        "08203": "Cañete",
        "08204": "Contulmo",
        "08205": "Curanilahue",
        "08206": "Los Álamos",
        "08207": "Tirúa",
        "08301": "Los Ángeles",
        "08302": "Antuco",
        "08303": "Cabrero",
        "08304": "Laja",
        "08305": "Mulchén",
        "08306": "Nacimiento",
        "08307": "Negrete",
        "08308": "Quilaco",
        "08309": "Quilleco",
        "08310": "San Rosendo",
        "08311": "Santa Bárbara",
        "08312": "Tucapel",
        "08313": "Yumbel",
        "08314": "Alto Biobío",
        "16101": "Chillán",
        "16102": "Bulnes",
        "16202": "Cobquecura",
        "16203": "Coelemu",
        "16302": "Coihueco",
        "16103": "Chillán Viejo",
        "16104": "El Carmen",
        "16204": "Ninhue",
        "16303": "Ñiquén",
        "16105": "Pemuco",
        "16106": "Pinto",
        "16205": "Portezuelo",
        "16107": "Quillón",
        "16201": "Quirihue",
        "16206": "Ránquil",
        "16301": "San Carlos",
        "16304": "San Fabián",
        "16108": "San Ignacio",
        "16305": "San Nicolás",
        "16207": "Treguaco",
        "16109": "Yungay",
        "09101": "Temuco",
        "09102": "Carahue",
        "09103": "Cunco",
        "09104": "Curarrehue",
        "09105": "Freire",
        "09106": "Galvarino",
        "09107": "Gorbea",
        "09108": "Lautaro",
        "09109": "Loncoche",
        "09110": "Melipeuco",
        "09111": "Nueva Imperial",
        "09112": "Padre Las Casas",
        "09113": "Perquenco",
        "09114": "Pitrufquén",
        "09115": "Pucón",
        "09116": "Saavedra",
        "09117": "Teodoro Schmidt",
        "09118": "Toltén",
        "09119": "Vilcún",
        "09120": "Villarrica",
        "09121": "Cholchol",
        "09201": "Angol",
        "09202": "Collipulli",
        "09203": "Curacautín",
        "09204": "Ercilla",
        "09205": "Lonquimay",
        "09206": "Los Sauces",
        "09207": "Lumaco",
        "09208": "Purén",
        "09209": "Renaico",
        "09210": "Traiguén",
        "09211": "Victoria",
        "14101": "Valdivia",
        "14102": "Corral",
        "14202": "Futrono",
        "14201": "La Unión",
        "14203": "Lago Ranco",
        "14103": "Lanco",
        "14104": "Los Lagos",
        "14105": "Máfil",
        "14106": "Mariquina",
        "14107": "Paillaco",
        "14108": "Panguipulli",
        "14204": "Río Bueno",
        "10101": "Puerto Montt",
        "10102": "Calbuco",
        "10103": "Cochamó",
        "10104": "Fresia",
        "10105": "Frutillar",
        "10106": "Los Muermos",
        "10107": "Llanquihue",
        "10108": "Maullín",
        "10109": "Puerto Varas",
        "10201": "Castro",
        "10202": "Ancud",
        "10203": "Chonchi",
        "10204": "Curaco de Vélez",
        "10205": "Dalcahue",
        "10206": "Puqueldón",
        "10207": "Queilén",
        "10208": "Quellón",
        "10209": "Quemchi",
        "10210": "Quinchao",
        "10301": "Osorno",
        "10302": "Puerto Octay",
        "10303": "Purranque",
        "10304": "Puyehue",
        "10305": "Río Negro",
        "10306": "San Juan de la Costa",
        "10307": "San Pablo",
        "10401": "Chaitén",
        "10402": "Futaleufú",
        "10403": "Hualaihué",
        "10404": "Palena",
        "11101": "Coihaique",
        "11102": "Lago Verde",
        "11201": "Aisén",
        "11202": "Cisnes",
        "11203": "Guaitecas",
        "11301": "Cochrane",
        "11302": "O'Higgins",
        "11303": "Tortel",
        "11401": "Chile Chico",
        "11402": "Río Ibáñez",
        "12101": "Punta Arenas",
        "12102": "Laguna Blanca",
        "12103": "Río Verde",
        "12104": "San Gregorio",
        "12201": "Cabo de Hornos",
        "12202": "Antártica",
        "12301": "Porvenir",
        "12302": "Primavera",
        "12303": "Timaukel",
        "12401": "Natales",
        "12402": "Torres del Paine",
        "13101": "Santiago",
        "13102": "Cerrillos",
        "13103": "Cerro Navia",
        "13104": "Conchalí",
        "13105": "El Bosque",
        "13106": "Estación Central",
        "13107": "Huechuraba",
        "13108": "Independencia",
        "13109": "La Cisterna",
        "13110": "La Florida",
        "13111": "La Granja",
        "13112": "La Pintana",
        "13113": "La Reina",
        "13114": "Las Condes",
        "13115": "Lo Barnechea",
        "13116": "Lo Espejo",
        "13117": "Lo Prado",
        "13118": "Macul",
        "13119": "Maipú",
        "13120": "Ñuñoa",
        "13121": "Pedro Aguirre Cerda",
        "13122": "Peñalolén",
        "13123": "Providencia",
        "13124": "Pudahuel",
        "13125": "Quilicura",
        "13126": "Quinta Normal",
        "13127": "Recoleta",
        "13128": "Renca",
        "13129": "San Joaquín",
        "13130": "San Miguel",
        "13131": "San Ramón",
        "13132": "Vitacura",
        "13201": "Puente Alto",
        "13202": "Pirque",
        "13203": "San José de Maipo",
        "13301": "Colina",
        "13302": "Lampa",
        "13303": "Tiltil",
        "13401": "San Bernardo",
        "13402": "Buin",
        "13403": "Calera de Tango",
        "13404": "Paine",
        "13501": "Melipilla",
        "13502": "Alhué",
        "13503": "Curacaví",
        "13504": "María Pinto",
        "13505": "San Pedro",
        "13601": "Talagante",
        "13602": "El Monte",
        "13603": "Isla de Maipo",
        "13604": "Padre Hurtado",
        "13605": "Peñaflor",
    }

    street_prefixes = OrderedDict(
        [
            ("Calle", 0.6),
            ("Avenida", 0.1),
            ("Avda.", 0.1),
            ("Av.", 0.1),
            ("Pasaje", 0.04),
            ("Psje.", 0.04),
            ("Camino", 0.02),
        ]
    )

    street_suffixes = (
        "Norte",
        "Sur",
    )

    city_formats = ("{{city}}",)

    street_name_formats = (
        "{{street_prefix}} {{common_street_name}}",
        "{{street_prefix}} {{historic_people_street_name}}",
        "{{street_prefix}} {{first_name_male}} {{last_name}}",
        "{{street_prefix}} {{first_name_female}} {{last_name}}",
        "{{street_prefix}} {{plant_street_name}}",
        "{{common_street_name}}",
        "{{historic_people_street_name}}",
        "{{plant_street_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
    )

    building_number_formats = OrderedDict(
        [
            ("%###", 0.35),
            ("%##", 0.35),
            ("%#", 0.25),
            ("%", 0.05),
        ]
    )

    street_address_formats = (
        "{{street_name}} {{building_number}}",
        "{{street_name}} {{building_number}} {{secondary_address}}",
    )

    address_formats = OrderedDict(
        [
            ("{{street_address}}\n{{commune_and_region}}, {{postcode}}", 0.4),
            ("{{street_address}}\n{{commune_and_region}}", 0.4),
            ("{{highway_name}}, km {{random_int:big_kilometer}}", 0.1),
            ("{{road_name}}, km {{random_int:kilometer}}, {{region}}", 0.1),
        ]
    )

    secondary_address_formats = ("Dpto. @@##", "Piso @#", "Of. %##@")

    common_street_names = OrderedDict(
        [
            ("Arturo Prat", 0.118812),
            ("Esmeralda", 0.107261),
            ("Manuel Rodríguez", 0.105611),
            ("Gabriela Mistral", 0.104785),
            ("Los Aromos", 0.104785),
            ("Las Rosas", 0.098185),
            ("Caupolicán", 0.094884),
            ("Lautaro", 0.094059),
            ("Los Alerces", 0.086634),
            ("Los Copihues", 0.084983),
        ]
    )

    # Some chilean historic people. Full names come first, then its variants
    historic_people_street_names = (
        ("Alonso de Ercilla",),
        ("Alonso de Ribera",),
        ("Álvaro Casanova", "Casanova"),
        ("Aníbal Pinto Garmendia", "Aníbal Pinto"),
        ("Antonio Varas",),
        ("Arturo Alessandri Palma", "Arturo Alessandri"),
        ("Benjamín Vicuña Mackenna", "Vicuña Mackenna", "Mackenna"),
        ("Bernardo O'Higgins", "O'Higgins"),
        ("Camilo Henríquez",),
        ("Caupolicán",),
        ("Colo Colo",),
        ("Diego Barros Arana", "Barros Arana"),
        ("Diego Portales", "Portales"),
        ("Domingo Santa María", "Santa María"),
        ("Eliodoro Yáñez",),
        ("Enrique Mac Iver", "Mac Iver"),
        ("Eusebio Lillo",),
        ("Francisco Bilbao", "Bilbao"),
        ("José de San Martín", "San Martín"),
        ("José Manuel Balmaceda", "Balmaceda"),
        ("José Miguel Carrera",),
        ("José Victorino Lastarria", "Lastarria"),
        ("Juan Mackenna",),
        ("Lord Thomas Cochrane", "Lord Cochrane", "Cochrane"),
        ("Los Carrera",),
        ("Manuel Antonio Matta", "Matta"),
        ("Manuel Bulnes", "Bulnes"),
        ("Manuel José Irarrázaval", "Irarrázabal"),
        ("Manuel Montt",),
        ("Manuel Rodríguez",),
        ("Manuel Baquedano", "Baquedano"),
        ("Michimalonco",),
        ("Padre Alberto Hurtado", "Alberto Hurtado"),
        ("Patricio Lynch", "Lynch"),
        ("Paula Jaraquemada",),
        ("Pedro Aguirre Cerda",),
        ("Pedro de Valdivia",),
        ("Pedro Montt",),
        ("Ramón Barros Luco", "Barros Luco"),
        ("Ramón Carnicer",),
        ("Ramón Freire", "Freire"),
        ("Ramón Picarte", "Picarte"),
        ("Salvador Allende Gossens", "Salvador Allende"),
        ("Santa Rosa",),
    )

    # Some streets are named by plants
    plant_street_names: ElementsType[str] = (
        "Los Cactus",
        "Los Laureles",
        "Los Piñones",
        "Los Helechos",
        "Los Higos",
        "Los Abedules",
        "Los Encinos",
        "Los Palmitos",
        "Los Naranjos",
        "Los Robles",
        "Los Pinos",
        "Los Coihues",
        "Los Calafates",
        "Los Digitales",
        "Los Lirios",
        "Los Tilos",
        "Los Girasoles",
        "Las Azucenas",
        "Las Lilas",
        "Las Hortensias",
        "Las Margaritas",
        "Las Maravillas",
        "Las Manzanillas",
        "Las Mandarinas",
        "Las Araucarias",
        "Las Mosquetas",
        "Las Malvas",
        "Las Mosquetas",
    )

    road_names = ("Ruta T-%#", "Ruta U-%##", "Ruta %##-CH")
    highway_names = ("Ruta 5 Norte", "Ruta 5 Sur")

    def commune(self) -> str:
        return self.random_element(self.communes.values())

    def province(self) -> str:
        return self.random_element(self.provinces.values())

    def region(self) -> str:
        return self.random_element(self.regions.values())

    def commune_code(self) -> str:
        return self.random_element(self.communes.keys())

    def province_code(self) -> str:
        return self.random_element(self.provinces.keys())

    def region_code(self) -> str:
        return self.random_element(self.regions.keys())

    def common_street_name(self) -> str:
        return self.random_element(self.common_street_names)

    def plant_street_name(self) -> str:
        return self.random_element(self.plant_street_names)

    def historic_people_street_name(self) -> str:
        person_names: Tuple[str, ...] = self.random_element(self.historic_people_street_names)
        return self.random_element(person_names)

    def street_prefix(self) -> str:
        return self.random_element(self.street_prefixes)

    def secondary_address(self) -> str:
        return self.numerify(self.random_element(self.secondary_address_formats))

    def commune_and_region(self) -> str:
        commune_code = self.commune_code()
        commune_name = self.communes[commune_code]
        region_index = int(commune_code[0:2]) - 1
        region_name = tuple(self.regions.values())[region_index]

        return f"{commune_name:s}, {region_name:s}"

    def road_name(self) -> str:
        self.generator.set_arguments("kilometer", {"min": 1, "max": 35})
        return self.numerify(self.generator.parse(self.random_element(self.road_names)))

    def highway_name(self) -> str:
        self.generator.set_arguments("big_kilometer", {"min": 1, "max": 1000})
        return self.numerify(self.generator.parse(self.random_element(self.highway_names)))

    def postcode(self) -> str:
        return self.numerify("######0")

    administrative_unit = region
    city = commune



from typing import Tuple

from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_male = (
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}-{{last_name}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}} {{suffix_male}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}} {{suffix_male}}",
    )

    formats_female = (
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}-{{last_name}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}} {{suffix_female}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}} {{suffix_female}}",
    )

    formats = formats_male + formats_female

    # From
    # http://de.wiktionary.org/wiki/Verzeichnis:Deutsch/Liste_der_h%C3%A4ufigsten_m%C3%A4nnlichen_Vornamen_Deutschlands
    first_names_male = (
        "Abbas",
        "Abdul",
        "Abdullah",
        "Abraham",
        "Abram",
        "Achim",
        "Ada",
        "Adalbert",
        "Adam",
        "Adelbert",
        "Adem",
        "Adolf",
        "Adrian",
        "Ahmad",
        "Ahmed",
        "Ahmet",
        "Alan",
        "Alban",
        "Albert",
        "Alberto",
        "Albin",
        "Albrecht",
        "Aldo",
        "Aleksandar",
        "Aleksander",
        "Aleksandr",
        "Aleksej",
        "Alessandro",
        "Alex",
        "Alexander",
        "Alexandre",
        "Alexandros",
        "Alexei",
        "Alexej",
        "Alf",
        "Alfons",
        "Alfonso",
        "Alfred",
        "Alfredo",
        "Ali",
        "Alois",
        "Aloys",
        "Alwin",
        "Amir",
        "Anastasios",
        "Anatol",
        "Anatoli",
        "Anatolij",
        "Andre",
        "Andreas",
        "Andree",
        "Andrei",
        "Andrej",
        "Andres",
        "Andrew",
        "Andrey",
        "Andrzej",
        "André",
        "Andy",
        "Angelo",
        "Anselm",
        "Ansgar",
        "Ante",
        "Anthony",
        "Anto",
        "Anton",
        "Antonino",
        "Antonio",
        "Antonios",
        "Antonius",
        "Apostolos",
        "Aribert",
        "Arif",
        "Armin",
        "Arnd",
        "Arndt",
        "Arne",
        "Arnfried",
        "Arnim",
        "Arno",
        "Arnold",
        "Arnulf",
        "Arthur",
        "Artur",
        "Athanasios",
        "Attila",
        "August",
        "Augustin",
        "Axel",
        "Aziz",
        "Baldur",
        "Balthasar",
        "Baptist",
        "Bartholomäus",
        "Bastian",
        "Bayram",
        "Bekir",
        "Bela",
        "Ben",
        "Benedikt",
        "Benjamin",
        "Benno",
        "Berend",
        "Bernard",
        "Bernd",
        "Bernd-Dieter",
        "Berndt",
        "Bernfried",
        "Bernhard",
        "Bernt",
        "Bernward",
        "Bert",
        "Berthold",
        "Bertold",
        "Bertram",
        "Birger",
        "Björn",
        "Bodo",
        "Bogdan",
        "Boris",
        "Branko",
        "Brian",
        "Bruno",
        "Burckhard",
        "Burghard",
        "Burkard",
        "Burkhard",
        "Burkhardt",
        "Calogero",
        "Carl",
        "Carl-Heinz",
        "Carlo",
        "Carlos",
        "Carmelo",
        "Carsten",
        "Celal",
        "Cemal",
        "Cemil",
        "Cengiz",
        "Cetin",
        "Charles",
        "Christian",
        "Christof",
        "Christoph",
        "Christopher",
        "Christos",
        "Claas",
        "Claudio",
        "Claudius",
        "Claus",
        "Claus-Dieter",
        "Claus-Peter",
        "Clemens",
        "Conrad",
        "Constantin",
        "Cord",
        "Cornelius",
        "Cosimo",
        "Curt",
        "Czeslaw",
        "Dagobert",
        "Damian",
        "Dan",
        "Daniel",
        "Daniele",
        "Danilo",
        "Danny",
        "Darius",
        "Dariusz",
        "Darko",
        "David",
        "Denis",
        "Dennis",
        "Denny",
        "Detlef",
        "Detlev",
        "Diedrich",
        "Dierk",
        "Dieter",
        "Diethard",
        "Diethelm",
        "Diether",
        "Dietmar",
        "Dietrich",
        "Dimitri",
        "Dimitrios",
        "Dino",
        "Dirk",
        "Ditmar",
        "Dittmar",
        "Dogan",
        "Domenico",
        "Dominic",
        "Dominik",
        "Donald",
        "Dragan",
        "Drago",
        "Dursun",
        "Dusan",
        "Eberhard",
        "Eberhardt",
        "Eckard",
        "Eckart",
        "Eckehard",
        "Eckhard",
        "Eckhardt",
        "Eckhart",
        "Edelbert",
        "Edgar",
        "Edmund",
        "Eduard",
        "Edward",
        "Edwin",
        "Egbert",
        "Eggert",
        "Egon",
        "Ehrenfried",
        "Ehrhard",
        "Eitel",
        "Ekkehard",
        "Ekkehart",
        "Ekrem",
        "Elias",
        "Elmar",
        "Emanuel",
        "Emil",
        "Emin",
        "Emmerich",
        "Engelbert",
        "Engin",
        "Enno",
        "Enrico",
        "Enver",
        "Ercan",
        "Erdal",
        "Erdogan",
        "Erhard",
        "Erhardt",
        "Eric",
        "Erich",
        "Erik",
        "Erkan",
        "Ernest",
        "Ernst",
        "Ernst-August",
        "Ernst-Dieter",
        "Ernst-Otto",
        "Erol",
        "Erwin",
        "Eugen",
        "Evangelos",
        "Ewald",
        "Fabian",
        "Falk",
        "Falko",
        "Faruk",
        "Fatih",
        "Fedor",
        "Felix",
        "Ferdi",
        "Ferdinand",
        "Ferenc",
        "Fernando",
        "Filippo",
        "Florian",
        "Folker",
        "Folkert",
        "Francesco",
        "Francis",
        "Francisco",
        "Franco",
        "Franjo",
        "Frank",
        "Frank-Michael",
        "Frank-Peter",
        "Franz",
        "Franz Josef",
        "Franz-Josef",
        "Franz-Peter",
        "Franz-Xaver",
        "Fred",
        "Freddy",
        "Frederic",
        "Frederik",
        "Fredi",
        "Fredo",
        "Fredy",
        "Fridolin",
        "Friedbert",
        "Friedemann",
        "Frieder",
        "Friedhelm",
        "Friedhold",
        "Friedo",
        "Friedrich",
        "Friedrich-Karl",
        "Friedrich-Wilhelm",
        "Frithjof",
        "Fritz",
        "Gabor",
        "Gabriel",
        "Gaetano",
        "Gebhard",
        "Geert",
        "Georg",
        "George",
        "Georgios",
        "Gerald",
        "Gerard",
        "Gerd",
        "Gereon",
        "Gerfried",
        "Gerhard",
        "Gerhardt",
        "Gerhart",
        "German",
        "Gernot",
        "Gero",
        "Gerold",
        "Gerolf",
        "Gert",
        "Gerwin",
        "Gilbert",
        "Gino",
        "Giorgio",
        "Giovanni",
        "Gisbert",
        "Giuseppe",
        "Goran",
        "Gordon",
        "Gottfried",
        "Gotthard",
        "Gotthilf",
        "Gotthold",
        "Gottlieb",
        "Gottlob",
        "Gregor",
        "Grzegorz",
        "Guenter",
        "Guenther",
        "Guido",
        "Guiseppe",
        "Gunar",
        "Gundolf",
        "Gunnar",
        "Gunter",
        "Gunther",
        "Guntram",
        "Gustav",
        "Götz",
        "Günter",
        "Günther",
        "H.-Dieter",
        "Hagen",
        "Hajo",
        "Hakan",
        "Halil",
        "Hannes",
        "Hanni",
        "Hanno",
        "Hanns",
        "Hans",
        "Hans D.",
        "Hans Dieter",
        "Hans Georg",
        "Hans Josef",
        "Hans Jörg",
        "Hans Jürgen",
        "Hans Peter",
        "Hans-Adolf",
        "Hans-Albert",
        "Hans-Bernd",
        "Hans-Christian",
        "Hans-Detlef",
        "Hans-Dieter",
        "Hans-Dietrich",
        "Hans-Eberhard",
        "Hans-Erich",
        "Hans-Friedrich",
        "Hans-Georg",
        "Hans-Gerd",
        "Hans-Gerhard",
        "Hans-Günter",
        "Hans-Günther",
        "Hans-H.",
        "Hans-Heinrich",
        "Hans-Helmut",
        "Hans-Henning",
        "Hans-Herbert",
        "Hans-Hermann",
        "Hans-Hinrich",
        "Hans-J.",
        "Hans-Joachim",
        "Hans-Jochen",
        "Hans-Josef",
        "Hans-Jörg",
        "Hans-Jürgen",
        "Hans-Karl",
        "Hans-Ludwig",
        "Hans-Martin",
        "Hans-Michael",
        "Hans-Otto",
        "Hans-Peter",
        "Hans-Rainer",
        "Hans-Rudolf",
        "Hans-Theo",
        "Hans-Ulrich",
        "Hans-Uwe",
        "Hans-Walter",
        "Hans-Werner",
        "Hans-Wilhelm",
        "Hans-Willi",
        "Hans-Wolfgang",
        "Hansgeorg",
        "Hansjoachim",
        "Hansjörg",
        "Hansjürgen",
        "Hanspeter",
        "Harald",
        "Hardy",
        "Harm",
        "Harold",
        "Harri",
        "Harro",
        "Harry",
        "Hartmut",
        "Hartmuth",
        "Hartwig",
        "Hasan",
        "Hassan",
        "Hasso",
        "Heiko",
        "Heimo",
        "Heiner",
        "Heinfried",
        "Heini",
        "Heino",
        "Heinrich",
        "Heinz",
        "Heinz Dieter",
        "Heinz-Dieter",
        "Heinz-Georg",
        "Heinz-Gerd",
        "Heinz-Günter",
        "Heinz-Günther",
        "Heinz-Joachim",
        "Heinz-Josef",
        "Heinz-Jürgen",
        "Heinz-Otto",
        "Heinz-Peter",
        "Heinz-Walter",
        "Heinz-Werner",
        "Heinz-Wilhelm",
        "Heinz-Willi",
        "Helfried",
        "Helge",
        "Hellmut",
        "Hellmuth",
        "Helmar",
        "Helmut",
        "Helmuth",
        "Hendrik",
        "Henner",
        "Henning",
        "Henrik",
        "Henry",
        "Henryk",
        "Herbert",
        "Heribert",
        "Hermann",
        "Hermann Josef",
        "Hermann-Josef",
        "Herrmann",
        "Herwig",
        "Hilmar",
        "Hinrich",
        "Holger",
        "Holm",
        "Horst",
        "Horst-Dieter",
        "Horst-Günter",
        "Horst-Peter",
        "Hubert",
        "Hubertus",
        "Hugo",
        "Hüseyin",
        "Ian",
        "Ibrahim",
        "Ignatz",
        "Ignaz",
        "Igor",
        "Ilhan",
        "Ilias",
        "Ilija",
        "Ilja",
        "Immo",
        "Imre",
        "Ingbert",
        "Ingmar",
        "Ingo",
        "Ingolf",
        "Ioannis",
        "Isidor",
        "Ismail",
        "Ismet",
        "Istvan",
        "Ivan",
        "Ivo",
        "Iwan",
        "Jacek",
        "Jacob",
        "Jakob",
        "James",
        "Jan",
        "Jan-Peter",
        "Janko",
        "Jann",
        "Janos",
        "Janus",
        "Janusz",
        "Jaroslav",
        "Jaroslaw",
        "Jens",
        "Jens-Peter",
        "Jens-Uwe",
        "Jerzy",
        "Jiri",
        "Joachim",
        "Jobst",
        "Jochem",
        "Jochen",
        "Joerg",
        "Johan",
        "Johann",
        "Johannes",
        "John",
        "Jonas",
        "Jonas",
        "Jonathan",
        "Jorge",
        "Jose",
        "Josef",
        "Joseph",
        "Josip",
        "Jost",
        "José",
        "Jovan",
        "Jozef",
        "Juan",
        "Juergen",
        "Julian",
        "Julius",
        "Juri",
        "Jurij",
        "Justus",
        "Jörg",
        "Jörg-Peter",
        "Jörgen",
        "Jörn",
        "Jürgen",
        "Kai-Uwe",
        "Kamil",
        "Karl",
        "Karl Heinz",
        "Karl-August",
        "Karl-Dieter",
        "Karl-Ernst",
        "Karl-Friedrich",
        "Karl-Georg",
        "Karl-Hans",
        "Karl-Heinrich",
        "Karl-Heinz",
        "Karl-Hermann",
        "Karl-Josef",
        "Karl-Jürgen",
        "Karl-Ludwig",
        "Karl-Otto",
        "Karl-Peter",
        "Karl-Werner",
        "Karl-Wilhelm",
        "Karlfried",
        "Karlheinz",
        "Karsten",
        "Kasimir",
        "Kaspar",
        "Kay-Uwe",
        "Kazim",
        "Kemal",
        "Kenan",
        "Kenneth",
        "Kevin",
        "Kilian",
        "Klaas",
        "Klaus",
        "Klaus Dieter",
        "Klaus Peter",
        "Klaus-D.",
        "Klaus-Dieter",
        "Klaus-Günter",
        "Klaus-Jürgen",
        "Klaus-Michael",
        "Klaus-Peter",
        "Klaus-Ulrich",
        "Klaus-Werner",
        "Klemens",
        "Knud",
        "Knut",
        "Konrad",
        "Konstantin",
        "Konstantinos",
        "Korbinian",
        "Kornelius",
        "Kristian",
        "Krzysztof",
        "Kunibert",
        "Kuno",
        "Kurt",
        "Ladislaus",
        "Lambert",
        "Lars",
        "Laszlo",
        "Laurenz",
        "Leander",
        "Leif",
        "Leo",
        "Leon",
        "Leonard",
        "Leonardo",
        "Leonhard",
        "Leonid",
        "Leopold",
        "Leszek",
        "Linus",
        "Lorenz",
        "Lorenzo",
        "Lothar",
        "Louis",
        "Luciano",
        "Ludger",
        "Ludwig",
        "Luigi",
        "Luis",
        "Lukas",
        "Lutz",
        "Magnus",
        "Mahmoud",
        "Mahmut",
        "Maik",
        "Malte",
        "Manfred",
        "Manuel",
        "Marc",
        "Marcel",
        "Marco",
        "Marcus",
        "Marek",
        "Marian",
        "Marijan",
        "Mario",
        "Marius",
        "Mariusz",
        "Mark",
        "Marko",
        "Markus",
        "Marten",
        "Martin",
        "Marvin",
        "Massimo",
        "Mathias",
        "Mato",
        "Matteo",
        "Matthias",
        "Matthäus",
        "Mattias",
        "Maurice",
        "Maurizio",
        "Max",
        "Maxim",
        "Maximilian",
        "Mehdi",
        "Mehmet",
        "Meik",
        "Meinhard",
        "Meinolf",
        "Meinrad",
        "Mesut",
        "Metin",
        "Micha",
        "Michael",
        "Michail",
        "Michel",
        "Miguel",
        "Mijo",
        "Mike",
        "Mikhail",
        "Milan",
        "Milos",
        "Miodrag",
        "Mirco",
        "Mirko",
        "Miroslav",
        "Miroslaw",
        "Mohamed",
        "Mohammad",
        "Mohammed",
        "Moritz",
        "Muharrem",
        "Murat",
        "Mustafa",
        "Muzaffer",
        "Necati",
        "Nick",
        "Nico",
        "Nicolai",
        "Nicolas",
        "Nicolaus",
        "Niels",
        "Niklas",
        "Niko",
        "Nikola",
        "Nikolai",
        "Nikolaj",
        "Nikolaos",
        "Nikolas",
        "Nikolaus",
        "Nils",
        "Norbert",
        "Norman",
        "Nurettin",
        "Nuri",
        "Olaf",
        "Ole",
        "Oliver",
        "Orhan",
        "Ortwin",
        "Oscar",
        "Oskar",
        "Osman",
        "Oswald",
        "Oswin",
        "Otfried",
        "Othmar",
        "Otmar",
        "Ottfried",
        "Ottmar",
        "Otto",
        "Ottokar",
        "Ottomar",
        "Paolo",
        "Pascal",
        "Pasquale",
        "Patric",
        "Patrick",
        "Patrik",
        "Paul",
        "Paul-Gerhard",
        "Paul-Heinz",
        "Paulo",
        "Pavel",
        "Pawel",
        "Pedro",
        "Peer",
        "Pero",
        "Petar",
        "Peter",
        "Peter-Michael",
        "Petros",
        "Philip",
        "Philipp",
        "Philippe",
        "Phillip",
        "Pierre",
        "Pietro",
        "Piotr",
        "Pirmin",
        "Pius",
        "Rafael",
        "Raik",
        "Raimund",
        "Rainer",
        "Ralf",
        "Ralf-Dieter",
        "Ralf-Peter",
        "Ralph",
        "Ramazan",
        "Ramon",
        "Randolf",
        "Raphael",
        "Raymond",
        "Raymund",
        "Recep",
        "Reginald",
        "Reimar",
        "Reimer",
        "Reimund",
        "Reinald",
        "Reiner",
        "Reinhard",
        "Reinhardt",
        "Reinhart",
        "Reinhold",
        "Remo",
        "Renato",
        "Rene",
        "René",
        "Reza",
        "Ricardo",
        "Richard",
        "Rico",
        "Rigo",
        "Riza",
        "Robby",
        "Robert",
        "Roberto",
        "Robin",
        "Rocco",
        "Rochus",
        "Roderich",
        "Roger",
        "Roland",
        "Rolf",
        "Rolf-Dieter",
        "Rolf-Peter",
        "Roman",
        "Romuald",
        "Ron",
        "Ronald",
        "Ronny",
        "Rouven",
        "Roy",
        "Ruben",
        "Rudi",
        "Rudolf",
        "Rudolph",
        "Rupert",
        "Ryszard",
        "Rüdiger",
        "Saban",
        "Sabri",
        "Sahin",
        "Salih",
        "Salvatore",
        "Sami",
        "Samir",
        "Samuel",
        "Sandor",
        "Sandro",
        "Sebastian",
        "Sebastiano",
        "Sedat",
        "Selim",
        "Senol",
        "Sepp",
        "Serge",
        "Sergei",
        "Sergej",
        "Sergio",
        "Severin",
        "Siegbert",
        "Siegfried",
        "Sieghard",
        "Siegmar",
        "Siegmund",
        "Siegward",
        "Sigfried",
        "Sigismund",
        "Sigmar",
        "Sigmund",
        "Sigurd",
        "Silvester",
        "Silvio",
        "Simon",
        "Slavko",
        "Slawomir",
        "Slobodan",
        "Stanislaus",
        "Stanislav",
        "Stanislaw",
        "Stavros",
        "Stefan",
        "Stefano",
        "Steffen",
        "Stephan",
        "Stephen",
        "Steve",
        "Steven",
        "Stjepan",
        "Sven",
        "Swen",
        "Sylvester",
        "Sylvio",
        "Sönke",
        "Sören",
        "Sükrü",
        "Süleyman",
        "Tadeusz",
        "Tassilo",
        "Thaddäus",
        "Theo",
        "Theobald",
        "Theodor",
        "Theodoros",
        "Thies",
        "Thilo",
        "Thomas",
        "Thoralf",
        "Thorben",
        "Thorsten",
        "Tibor",
        "Till",
        "Tillmann",
        "Tilman",
        "Tilmann",
        "Tilo",
        "Tim",
        "Timm",
        "Timo",
        "Tino",
        "Tobias",
        "Tom",
        "Tomas",
        "Tomasz",
        "Tomislav",
        "Toni",
        "Tony",
        "Toralf",
        "Torben",
        "Torsten",
        "Traugott",
        "Udo",
        "Ulf",
        "Uli",
        "Ullrich",
        "Ulrich",
        "Urban",
        "Urs",
        "Utz",
        "Uwe",
        "Vadim",
        "Valentin",
        "Valerij",
        "Vassilios",
        "Veit",
        "Veli",
        "Victor",
        "Viktor",
        "Vincent",
        "Vincenzo",
        "Vinko",
        "Vinzenz",
        "Vitali",
        "Vito",
        "Vittorio",
        "Vitus",
        "Vladimir",
        "Vlado",
        "Volker",
        "Volkhard",
        "Volkmar",
        "Waldemar",
        "Walfried",
        "Walter",
        "Walther",
        "Wenzel",
        "Werner",
        "Wieland",
        "Wieslaw",
        "Wigbert",
        "Wilfried",
        "Wilhelm",
        "Willfried",
        "Willi",
        "William",
        "Willibald",
        "Willibert",
        "Willy",
        "Winfried",
        "Witold",
        "Wladimir",
        "Wojciech",
        "Woldemar",
        "Wolf",
        "Wolf-Dieter",
        "Wolf-Dietrich",
        "Wolf-Rüdiger",
        "Wolfgang",
        "Wolfhard",
        "Wolfram",
        "Wulf",
        "Xaver",
        "Yilmaz",
        "Yusuf",
        "Zbigniew",
        "Zdravko",
        "Zeki",
        "Zeljko",
        "Zenon",
        "Zlatko",
        "Zoltan",
        "Zoran",
    )

    # From
    # http://de.wiktionary.org/wiki/Verzeichnis:Deutsch/Liste_der_h%C3%A4ufigsten_weiblichen_Vornamen_Deutschlands
    first_names_female = (
        "Adele",
        "Adelgunde",
        "Adelheid",
        "Adelinde",
        "Adeline",
        "Adina",
        "Adolfine",
        "Adriana",
        "Adriane",
        "Aenne",
        "Änne",
        "Agata",
        "Agatha",
        "Agathe",
        "Agnes",
        "Agnieszka",
        "Albertine",
        "Albina",
        "Aleksandra",
        "Alena",
        "Alexa",
        "Alexandra",
        "Alice",
        "Alicia",
        "Alicja",
        "Alida",
        "Alina",
        "Aline",
        "Alla",
        "Alma",
        "Almut",
        "Almuth",
        "Aloisia",
        "Alwina",
        "Alwine",
        "Amalia",
        "Amalie",
        "Amanda",
        "Amelie",
        "Ana",
        "Anastasia",
        "Andrea",
        "Aneta",
        "Anett",
        "Anette",
        "Angela",
        "Angelica",
        "Angelika",
        "Angelina",
        "Angelique",
        "Anica",
        "Anika",
        "Anita",
        "Anja",
        "Anka",
        "Anke",
        "Ann",
        "Ann-Kathrin",
        "Anna",
        "Anna-Lena",
        "Anna-Luise",
        "Anna-Maria",
        "Anna-Marie",
        "Annaliese",
        "Annamaria",
        "Anne",
        "Anne-Kathrin",
        "Anne-Katrin",
        "Anne-Marie",
        "Anne-Rose",
        "Annedore",
        "Annegret",
        "Annegrete",
        "Annekatrin",
        "Anneke",
        "Annelene",
        "Anneli",
        "Annelie",
        "Annelies",
        "Anneliese",
        "Annelise",
        "Annelore",
        "Annemarie",
        "Annemie",
        "Annerose",
        "Annett",
        "Annette",
        "Anni",
        "Annie",
        "Annika",
        "Annita",
        "Anny",
        "Antje",
        "Antoinette",
        "Antonia",
        "Antonie",
        "Antonietta",
        "Antonina",
        "Apollonia",
        "Ariane",
        "Arzu",
        "Asta",
        "Astrid",
        "Augusta",
        "Auguste",
        "Aurelia",
        "Aynur",
        "Ayse",
        "Aysel",
        "Ayten",
        "Babett",
        "Babette",
        "Barbara",
        "Beata",
        "Beate",
        "Beatrice",
        "Beatrix",
        "Belinda",
        "Benita",
        "Berit",
        "Bernadette",
        "Bernhardine",
        "Berta",
        "Bertha",
        "Betina",
        "Betti",
        "Bettina",
        "Betty",
        "Bianca",
        "Bianka",
        "Birgid",
        "Birgit",
        "Birgitt",
        "Birgitta",
        "Birte",
        "Birthe",
        "Blanka",
        "Bozena",
        "Branka",
        "Brigitta",
        "Brigitte",
        "Brit",
        "Brita",
        "Britt",
        "Britta",
        "Brunhild",
        "Brunhilde",
        "Bruni",
        "Bärbel",
        "Camilla",
        "Canan",
        "Caren",
        "Carin",
        "Carina",
        "Carla",
        "Carmela",
        "Carmen",
        "Carmine",
        "Carola",
        "Carolin",
        "Carolina",
        "Caroline",
        "Caterina",
        "Catharina",
        "Catherine",
        "Cathleen",
        "Cathrin",
        "Catrin",
        "Cecilia",
        "Centa",
        "Chantal",
        "Charlotte",
        "Christa",
        "Christa-Maria",
        "Christel",
        "Christiana",
        "Christiane",
        "Christin",
        "Christina",
        "Christine",
        "Christl",
        "Cilli",
        "Cilly",
        "Cindy",
        "Claire",
        "Clara",
        "Clarissa",
        "Claudia",
        "Cläre",
        "Concetta",
        "Conny",
        "Constance",
        "Constanze",
        "Cora",
        "Cordula",
        "Corina",
        "Corinna",
        "Corinne",
        "Cornelia",
        "Cosima",
        "Cristina",
        "Cynthia",
        "Cäcilia",
        "Cäcilie",
        "Dagmar",
        "Dajana",
        "Damaris",
        "Dana",
        "Danica",
        "Daniela",
        "Danielle",
        "Danuta",
        "Daria",
        "Deborah",
        "Delia",
        "Denise",
        "Desiree",
        "Diana",
        "Diane",
        "Dietlind",
        "Dietlinde",
        "Dina",
        "Dolores",
        "Donata",
        "Dora",
        "Doreen",
        "Dorina",
        "Doris",
        "Dorit",
        "Dorle",
        "Dorota",
        "Dorothe",
        "Dorothea",
        "Dorothee",
        "Dragica",
        "Dunja",
        "Dörte",
        "Dörthe",
        "Edda",
        "Edelgard",
        "Edeltraud",
        "Edeltraut",
        "Edeltrud",
        "Edit",
        "Edith",
        "Editha",
        "Ehrentraud",
        "Eileen",
        "Ekaterina",
        "Elena",
        "Eleni",
        "Elenore",
        "Eleonora",
        "Eleonore",
        "Elfi",
        "Elfie",
        "Elfriede",
        "Elif",
        "Elisa",
        "Elisabet",
        "Elisabeth",
        "Elise",
        "Elizabeth",
        "Elke",
        "Ella",
        "Ellen",
        "Elli",
        "Ellinor",
        "Elly",
        "Elma",
        "Elsa",
        "Elsbeth",
        "Else",
        "Elvira",
        "Elwira",
        "Elzbieta",
        "Emilia",
        "Emilie",
        "Emine",
        "Emma",
        "Emmi",
        "Emmy",
        "Erdmute",
        "Erica",
        "Erika",
        "Erna",
        "Ernestine",
        "Ester",
        "Esther",
        "Etta",
        "Eugenia",
        "Eugenie",
        "Eva",
        "Eva-Maria",
        "Eva-Marie",
        "Evamaria",
        "Evangelia",
        "Evelin",
        "Eveline",
        "Evelyn",
        "Evelyne",
        "Evi",
        "Ewa",
        "Fabienne",
        "Fadime",
        "Fanny",
        "Fatima",
        "Fatma",
        "Felicia",
        "Felicitas",
        "Felizitas",
        "Filiz",
        "Flora",
        "Florence",
        "Florentine",
        "Franca",
        "Francesca",
        "Francoise",
        "Franka",
        "Franziska",
        "Frauke",
        "Frederike",
        "Freia",
        "Freya",
        "Frida",
        "Frieda",
        "Friedericke",
        "Friederike",
        "Friedhilde",
        "Friedl",
        "Friedlinde",
        "Gabi",
        "Gabriela",
        "Gabriele",
        "Gabriella",
        "Gaby",
        "Galina",
        "Genoveva",
        "Georgia",
        "Georgine",
        "Geraldine",
        "Gerda",
        "Gerdi",
        "Gerhild",
        "Gerlind",
        "Gerlinde",
        "Gerta",
        "Gerti",
        "Gertraud",
        "Gertraude",
        "Gertraut",
        "Gertrud",
        "Gertrude",
        "Gesa",
        "Gesche",
        "Gesine",
        "Geza",
        "Giesela",
        "Gilda",
        "Gina",
        "Giovanna",
        "Gisa",
        "Gisela",
        "Gislinde",
        "Gitta",
        "Gitte",
        "Giuseppina",
        "Gloria",
        "Gordana",
        "Grazyna",
        "Greta",
        "Gretchen",
        "Grete",
        "Gretel",
        "Gretl",
        "Grit",
        "Gudrun",
        "Gudula",
        "Gunda",
        "Gundel",
        "Gundi",
        "Gundula",
        "Gunhild",
        "Gusti",
        "Gönül",
        "Gülay",
        "Gülsen",
        "Gülten",
        "Halina",
        "Hanife",
        "Hanna",
        "Hannah",
        "Hannchen",
        "Hanne",
        "Hanne-Lore",
        "Hannelore",
        "Hanny",
        "Harriet",
        "Hatice",
        "Hedda",
        "Hedi",
        "Hedwig",
        "Hedy",
        "Heide",
        "Heide-Marie",
        "Heidelinde",
        "Heidelore",
        "Heidemarie",
        "Heiderose",
        "Heidi",
        "Heidrun",
        "Heike",
        "Helen",
        "Helena",
        "Helene",
        "Helga",
        "Hella",
        "Helma",
        "Helmtrud",
        "Henni",
        "Henny",
        "Henri",
        "Henriette",
        "Henrike",
        "Herlinde",
        "Herma",
        "Hermine",
        "Herta",
        "Hertha",
        "Hilda",
        "Hildburg",
        "Hilde",
        "Hildegard",
        "Hildegart",
        "Hildegund",
        "Hildegunde",
        "Hilma",
        "Hiltraud",
        "Hiltrud",
        "Hubertine",
        "Hulda",
        "Hülya",
        "Ida",
        "Ildiko",
        "Ilka",
        "Ilona",
        "Ilonka",
        "Ilse",
        "Imelda",
        "Imke",
        "Ina",
        "Ines",
        "Inga",
        "Inge",
        "Ingeborg",
        "Ingeburg",
        "Ingelore",
        "Ingetraud",
        "Ingetraut",
        "Ingrid",
        "Ingried",
        "Inka",
        "Inken",
        "Inna",
        "Insa",
        "Ira",
        "Irena",
        "Irene",
        "Irina",
        "Iris",
        "Irma",
        "Irmela",
        "Irmengard",
        "Irmgard",
        "Irmhild",
        "Irmi",
        "Irmingard",
        "Irmtraud",
        "Irmtraut",
        "Irmtrud",
        "Isa",
        "Isabel",
        "Isabell",
        "Isabella",
        "Isabelle",
        "Isolde",
        "Ivana",
        "Ivanka",
        "Ivonne",
        "Iwona",
        "Jacqueline",
        "Jadwiga",
        "Jana",
        "Jane",
        "Janet",
        "Janett",
        "Janette",
        "Janin",
        "Janina",
        "Janine",
        "Janna",
        "Jaqueline",
        "Jasmin",
        "Jasmina",
        "Jeanette",
        "Jeannette",
        "Jeannine",
        "Jelena",
        "Jennifer",
        "Jenny",
        "Jessica",
        "Jessika",
        "Jo",
        "Joana",
        "Joanna",
        "Johanna",
        "Johanne",
        "Jolanda",
        "Jolanta",
        "Jolanthe",
        "Josefa",
        "Josefine",
        "Josephine",
        "Judith",
        "Julia",
        "Juliana",
        "Juliane",
        "Julie",
        "Justina",
        "Justine",
        "Jutta",
        "Karen",
        "Karin",
        "Karina",
        "Karla",
        "Karola",
        "Karolin",
        "Karolina",
        "Karoline",
        "Kata",
        "Katalin",
        "Katarina",
        "Katarzyna",
        "Katerina",
        "Katharina",
        "Katharine",
        "Katherina",
        "Kathi",
        "Kathleen",
        "Kathrin",
        "Kathy",
        "Kati",
        "Katja",
        "Katrin",
        "Katy",
        "Kerstin",
        "Kira",
        "Kirsten",
        "Kirstin",
        "Klara",
        "Klaudia",
        "Klothilde",
        "Kläre",
        "Konstanze",
        "Kordula",
        "Korinna",
        "Kornelia",
        "Kreszentia",
        "Kreszenz",
        "Kriemhild",
        "Krista",
        "Kristiane",
        "Kristin",
        "Kristina",
        "Kristine",
        "Krystyna",
        "Kunigunda",
        "Kunigunde",
        "Käte",
        "Käthe",
        "Käthi",
        "Laila",
        "Lara",
        "Larissa",
        "Laura",
        "Lea",
        "Leila",
        "Lena",
        "Lene",
        "Leni",
        "Leokadia",
        "Leonie",
        "Leonore",
        "Leopoldine",
        "Leyla",
        "Lia",
        "Liane",
        "Lidia",
        "Lidija",
        "Lidwina",
        "Liesa",
        "Liesbeth",
        "Lieschen",
        "Liesel",
        "Lieselotte",
        "Lili",
        "Lilian",
        "Liliana",
        "Liliane",
        "Lilija",
        "Lilli",
        "Lilly",
        "Lilo",
        "Lina",
        "Linda",
        "Lioba",
        "Lisa",
        "Lisbeth",
        "Liselotte",
        "Lisette",
        "Lissi",
        "Lissy",
        "Ljiljana",
        "Ljubica",
        "Ljudmila",
        "Loni",
        "Lore",
        "Loretta",
        "Lotte",
        "Lotti",
        "Louise",
        "Lucia",
        "Lucie",
        "Ludmila",
        "Ludmilla",
        "Ludwina",
        "Luisa",
        "Luise",
        "Luitgard",
        "Luka",
        "Luzia",
        "Luzie",
        "Lydia",
        "Madeleine",
        "Madlen",
        "Magarete",
        "Magda",
        "Magdalena",
        "Magdalene",
        "Magret",
        "Magrit",
        "Maike",
        "Maja",
        "Malgorzata",
        "Mandy",
        "Manja",
        "Manuela",
        "Mara",
        "Marcella",
        "Mareen",
        "Mareike",
        "Mareile",
        "Maren",
        "Marga",
        "Margaret",
        "Margareta",
        "Margarete",
        "Margaretha",
        "Margarethe",
        "Margarita",
        "Margit",
        "Margita",
        "Margitta",
        "Margot",
        "Margret",
        "Margrit",
        "Maria",
        "Maria-Luise",
        "Maria-Theresia",
        "Mariana",
        "Marianna",
        "Marianne",
        "Marica",
        "Marie",
        "Marie-Louise",
        "Marie-Luise",
        "Marie-Theres",
        "Marie-Therese",
        "Mariechen",
        "Mariele",
        "Marieluise",
        "Marietta",
        "Marija",
        "Marika",
        "Marina",
        "Mariola",
        "Marion",
        "Marisa",
        "Marit",
        "Marita",
        "Maritta",
        "Marjan",
        "Marleen",
        "Marlen",
        "Marlene",
        "Marlies",
        "Marliese",
        "Marlis",
        "Marta",
        "Martha",
        "Martina",
        "Martine",
        "Mary",
        "Marzena",
        "Mathilde",
        "Maya",
        "Mechthild",
        "Mechthilde",
        "Mechtild",
        "Meike",
        "Melanie",
        "Melissa",
        "Melita",
        "Melitta",
        "Meral",
        "Mercedes",
        "Meryem",
        "Meta",
        "Mia",
        "Michaela",
        "Michaele",
        "Michelle",
        "Milena",
        "Milica",
        "Milka",
        "Mina",
        "Minna",
        "Mira",
        "Mirella",
        "Miriam",
        "Mirja",
        "Mirjam",
        "Mirjana",
        "Miroslawa",
        "Mona",
        "Monica",
        "Monika",
        "Monique",
        "Monja",
        "Myriam",
        "Nada",
        "Nadeschda",
        "Nadeshda",
        "Nadia",
        "Nadin",
        "Nadine",
        "Nadja",
        "Nancy",
        "Natali",
        "Natalia",
        "Natalie",
        "Natalija",
        "Natalja",
        "Natascha",
        "Nathalie",
        "Nelli",
        "Nelly",
        "Nermin",
        "Nevenka",
        "Nicole",
        "Nina",
        "Nora",
        "Norma",
        "Notburga",
        "Nuran",
        "Nuray",
        "Nurten",
        "Oda",
        "Olav",
        "Olena",
        "Olga",
        "Olivia",
        "Ortrud",
        "Ortrun",
        "Ottilie",
        "Oxana",
        "Pamela",
        "Paola",
        "Pascale",
        "Patricia",
        "Patrizia",
        "Paula",
        "Paulina",
        "Pauline",
        "Peggy",
        "Petra",
        "Philomena",
        "Pia",
        "Polina",
        "Priska",
        "Rabea",
        "Radmila",
        "Rahel",
        "Raisa",
        "Raissa",
        "Ramona",
        "Raphaela",
        "Rebecca",
        "Rebekka",
        "Regina",
        "Regine",
        "Reingard",
        "Reinhild",
        "Reinhilde",
        "Rena",
        "Renata",
        "Renate",
        "Reni",
        "Resi",
        "Ria",
        "Ricarda",
        "Rita",
        "Romana",
        "Romy",
        "Rosa",
        "Rosa-Maria",
        "Rosalia",
        "Rosalie",
        "Rosalinde",
        "Rose",
        "Rose-Marie",
        "Rosel",
        "Roselinde",
        "Rosemarie",
        "Rosi",
        "Rosina",
        "Rosita",
        "Rosl",
        "Rosmarie",
        "Roswita",
        "Roswitha",
        "Rotraud",
        "Rotraut",
        "Ruth",
        "Ruthild",
        "Sabina",
        "Sabine",
        "Sabrina",
        "Samira",
        "Sandra",
        "Sandy",
        "Sara",
        "Sarah",
        "Sarina",
        "Saskia",
        "Selma",
        "Semra",
        "Senta",
        "Serpil",
        "Sevim",
        "Sibel",
        "Sibilla",
        "Sibille",
        "Sibylla",
        "Sibylle",
        "Sieglinde",
        "Siegrid",
        "Siegried",
        "Siegrun",
        "Siglinde",
        "Sigrid",
        "Sigrun",
        "Silja",
        "Silke",
        "Silva",
        "Silvana",
        "Silvia",
        "Simona",
        "Simone",
        "Sina",
        "Sinaida",
        "Slavica",
        "Sofia",
        "Sofie",
        "Solveig",
        "Songül",
        "Sonia",
        "Sonja",
        "Sophia",
        "Sophie",
        "Stefani",
        "Stefania",
        "Stefanie",
        "Steffi",
        "Stella",
        "Stephanie",
        "Stilla",
        "Susan",
        "Susana",
        "Susann",
        "Susanna",
        "Susanne",
        "Suse",
        "Susi",
        "Suzanne",
        "Svea",
        "Svenja",
        "Svetlana",
        "Swantje",
        "Swetlana",
        "Sybilla",
        "Sybille",
        "Sylke",
        "Sylvana",
        "Sylvia",
        "Sylvie",
        "Sylwia",
        "Tabea",
        "Tamara",
        "Tania",
        "Tanja",
        "Tatiana",
        "Tatjana",
        "Telse",
        "Teresa",
        "Thea",
        "Theda",
        "Thekla",
        "Theodora",
        "Theres",
        "Theresa",
        "Therese",
        "Theresia",
        "Tilly",
        "Tina",
        "Traude",
        "Traudel",
        "Traudl",
        "Traute",
        "Trude",
        "Trudel",
        "Trudi",
        "Tülay",
        "Türkan",
        "Ulla",
        "Ulrike",
        "Undine",
        "Ursel",
        "Ursula",
        "Urszula",
        "Urte",
        "Uschi",
        "Uta",
        "Ute",
        "Valentina",
        "Valentine",
        "Valeri",
        "Valeria",
        "Valerie",
        "Valeska",
        "Vanessa",
        "Vera",
        "Verena",
        "Veronica",
        "Veronika",
        "Veronique",
        "Vesna",
        "Victoria",
        "Viktoria",
        "Viola",
        "Violetta",
        "Virginia",
        "Viviane",
        "Walburga",
        "Waldtraut",
        "Walentina",
        "Walli",
        "Wally",
        "Waltraud",
        "Waltraut",
        "Waltrud",
        "Wanda",
        "Wencke",
        "Wendelin",
        "Wenke",
        "Wera",
        "Wibke",
        "Wiebke",
        "Wilfriede",
        "Wilhelmine",
        "Wilma",
        "Wiltrud",
        "Xenia",
        "Yasemin",
        "Yasmin",
        "Yvette",
        "Yvonne",
        "Zdenka",
        "Zehra",
        "Zenta",
        "Zeynep",
        "Zita",
        "Zofia",
    )

    first_names = first_names_male + first_names_female

    # source
    # https://www.namenforschung.net/en/dfd/dictionary/list-of-all-published-entries/
    last_names = (
        "Ackermann",
        "Adler",
        "Adolph",
        "Albers",
        "Anders",
        "Atzler",
        "Aumann",
        "Austermühle",
        "Bachmann",
        "Bähr",
        "Bärer",
        "Barkholz",
        "Barth",
        "Bauer",
        "Baum",
        "Becker",
        "Beckmann",
        "Beer",
        "Beier",
        "Bender",
        "Benthin",
        "Berger",
        "Beyer",
        "Bien",
        "Biggen",
        "Binner",
        "Birnbaum",
        "Bloch",
        "Blümel",
        "Bohlander",
        "Bonbach",
        "Bolander",
        "Bolnbach",
        "Bolzmann",
        "Börner",
        "Bohnbach",
        "Boucsein",
        "Briemer",
        "Bruder",
        "Buchholz",
        "Budig",
        "Butte",
        "Carsten",
        "Caspar",
        "Christoph",
        "Cichorius",
        "Conradi",
        "Davids",
        "Dehmel",
        "Dietz",
        "Dippel",
        "Ditschlerin",
        "Dobes",
        "Döhn",
        "Döring",
        "Dörr",
        "Dörschner",
        "Dowerg",
        "Drewes",
        "Drub",
        "Drubin",
        "Dussen van",
        "Eberhardt",
        "Ebert",
        "Eberth",
        "Eckbauer",
        "Ehlert",
        "Eigenwillig",
        "Eimer",
        "Ernst",
        "Etzler",
        "Etzold",
        "Faust",
        "Fechner",
        "Fiebig",
        "Finke",
        "Fischer",
        "Flantz",
        "Fliegner",
        "Förster",
        "Franke",
        "Freudenberger",
        "Fritsch",
        "Fröhlich",
        "Gehringer",
        "Geisel",
        "Geisler",
        "Geißler",
        "Gerlach",
        "Gertz",
        "Gierschner",
        "Gieß",
        "Girschner",
        "Gnatz",
        "Gorlitz",
        "Gotthard",
        "Graf",
        "Grein Groth",
        "Gröttner",
        "Gude",
        "Gunpf",
        "Gumprich",
        "Gute",
        "Gutknecht",
        "Haase",
        "Haering",
        "Hänel",
        "Häring",
        "Hahn",
        "Hamann",
        "Hande",
        "Harloff",
        "Hartmann",
        "Hartung",
        "Hauffer",
        "Hecker",
        "Heidrich",
        "Hein",
        "Heinrich",
        "Heintze",
        "Heinz",
        "Hellwig",
        "Henck",
        "Hendriks",
        "Henk",
        "Henschel",
        "Hentschel",
        "Hering",
        "Hermann",
        "Herrmann",
        "Hermighausen",
        "Hertrampf",
        "Heser",
        "Heß",
        "Hesse",
        "Hettner",
        "Hethur",
        "Heuser",
        "Hiller",
        "Heydrich",
        "Höfig",
        "Hofmann",
        "Holsten",
        "Holt",
        "Holzapfel",
        "Hölzenbecher",
        "Hörle",
        "Hövel",
        "Hoffmann",
        "Hornich",
        "Hornig",
        "Hübel",
        "Huhn",
        "Jacob",
        "Jacobi Jäckel",
        "Jähn",
        "Jäkel",
        "Jäntsch",
        "Jessel",
        "Jockel",
        "Johann",
        "Jopich",
        "Junck",
        "Juncken",
        "Jungfer",
        "Junitz",
        "Junk",
        "Junken",
        "Jüttner",
        "Kabus",
        "Kade",
        "Käster",
        "Kallert",
        "Kambs",
        "Karge",
        "Karz",
        "Kaul",
        "Kensy",
        "Keudel",
        "Killer",
        "Kitzmann",
        "Klapp",
        "Klemm",
        "Klemt",
        "Klingelhöfer",
        "Klotz",
        "Knappe",
        "Kobelt",
        "Koch",
        "Koch II",
        "Köhler",
        "Köster",
        "Kohl",
        "Kostolzin",
        "Kramer",
        "Kranz",
        "Kraus",
        "Krause",
        "Kraushaar",
        "Krebs",
        "Krein",
        "Kreusel",
        "Kroker",
        "Kruschwitz",
        "Kuhl",
        "Kühnert",
        "Kusch",
        "Lachmann",
        "Ladeck",
        "Lange",
        "Langern",
        "Lehmann",
        "Liebelt",
        "Lindau",
        "Lindner",
        "Linke",
        "Löchel",
        "Löffler",
        "Loos",
        "Lorch",
        "Losekann",
        "Löwer",
        "Lübs",
        "Mälzer",
        "Mangold",
        "Mans",
        "Margraf",
        "Martin",
        "Matthäi",
        "Meister",
        "Mende",
        "Mentzel",
        "Metz",
        "Meyer",
        "Mielcarek",
        "Mies",
        "Misicher",
        "Mitschke",
        "Mohaupt",
        "Mosemann",
        "Möchlichen",
        "Mude",
        "Mühle",
        "Mülichen",
        "Müller",
        "Naser",
        "Nerger",
        "Nette",
        "Neureuther",
        "Neuschäfer",
        "Niemeier",
        "Noack",
        "Nohlmans",
        "Oderwald",
        "Oestrovsky",
        "Ortmann",
        "Otto",
        "Paffrath",
        "Pärtzelt",
        "Patberg",
        "Pechel",
        "Pergande",
        "Peukert",
        "Pieper",
        "Plath",
        "Pohl",
        "Pölitz",
        "Preiß",
        "Pruschke",
        "Putz",
        "Rädel",
        "Radisch",
        "Reichmann",
        "Reinhardt",
        "Reising",
        "Renner",
        "Reuter",
        "Riehl",
        "Ring",
        "Ritter",
        "Rogge",
        "Rogner",
        "Rohleder",
        "Röhrdanz",
        "Röhricht",
        "Roht",
        "Römer",
        "Rörricht",
        "Rose",
        "Rosemann",
        "Rosenow",
        "Roskoth",
        "Rudolph",
        "Ruppersberger",
        "Ruppert",
        "Rust",
        "Sager",
        "Salz",
        "Säuberlich",
        "Sauer",
        "Schaaf",
        "Schacht",
        "Schäfer",
        "Scheel",
        "Scheibe",
        "Schenk",
        "Scheuermann",
        "Schinke",
        "Schleich",
        "Schleich",
        "auch Schlauchin",
        "Schlosser",
        "Schmidt",
        "Schmidtke",
        "Schmiedecke",
        "Schmiedt",
        "Schönland",
        "Scholl",
        "Scholtz",
        "Scholz",
        "Schomber",
        "Schottin",
        "Schuchhardt",
        "Schüler",
        "Schulz",
        "Schuster",
        "Schweitzer",
        "Schwital",
        "Segebahn",
        "Seifert",
        "Seidel",
        "Seifert",
        "Seip",
        "Siering",
        "Söding",
        "Sölzer",
        "Sontag",
        "Sorgatz",
        "Speer",
        "Spieß",
        "Stadelmann",
        "Stahr",
        "Staude",
        "Steckel",
        "Steinberg",
        "Steuer",
        "Stey",
        "Stiebitz",
        "Stiffel",
        "Stoll",
        "Stolze",
        "Striebitz",
        "Stroh",
        "Stumpf",
        "Süßebier",
        "Täsche",
        "Textor",
        "Thanel",
        "Thies",
        "Tintzmann",
        "Tlustek",
        "Trapp",
        "Trommler",
        "Tröst",
        "Trub",
        "Trüb",
        "Trubin",
        "Trupp",
        "Tschentscher",
        "Ullmann",
        "Ullrich",
        "van der Dussen",
        "Vogt",
        "Vollbrecht",
        "Wagenknecht",
        "Wagner",
        "Wähner",
        "Walter",
        "Warmer",
        "Weihmann",
        "Weimer",
        "Weinhage",
        "Weinhold",
        "Weiß",
        "Weitzel",
        "Weller",
        "Wende",
        "Wernecke",
        "Werner",
        "Wesack",
        "Wiek",
        "Wieloch",
        "Wilms",
        "Wilmsen",
        "Winkler",
        "Wirth",
        "Wohlgemut",
        "Wulf",
        "Wulff",
        "Zahn",
        "Zänker",
        "Ziegert",
        "Zimmer",
        "Zirme",
        "Zobel",
        "Zorbach",
    )

    prefixes_male = (
        "Herr",
        "Dr.",
        "Ing.",
        "Dipl.-Ing.",
        "Prof.",
        "Univ.Prof.",
    )
    prefixes_female = (
        "Frau",
        "Dr.",
        "Ing.",
        "Dipl.-Ing.",
        "Prof.",
        "Univ.Prof.",
    )

    suffixes = ("B.Sc.", "B.A.", "B.Eng.", "MBA.")

    # Source: https://de.wikipedia.org/wiki/Familienstand
    civil_status_list = (
        ("LD", "ledig"),
        ("VH", "verheiratet"),
        ("VW", "verwitwet"),
        ("GS", "geschieden"),
        ("EA", "Ehe aufgehoben"),
        ("LP", "in eingetragener Lebenspartnerschaft"),
        ("LV", "durch Tod aufgelöste Lebenspartnerschaft"),
        ("LA", "aufgehobene Lebenspartnerschaft"),
        ("LE", "durch Todeserklärung aufgelöste Lebenspartnerschaft"),
        ("NB", "nicht bekannt"),
    )

    def civil_status(self) -> Tuple[str, str]:
        return self.random_element(self.civil_status_list)

    def civil_status_code(self) -> str:
        return self.random_element(self.civil_status_list)[0]

    def civil_status_name(self) -> str:
        return self.random_element(self.civil_status_list)[1]



from .. import Provider as CurrencyProvider


class Provider(CurrencyProvider):
    # Format: (code, name)
    currencies = (
        ("AED", "BAA Dirhami"),
        ("AFN", "Afg‘oni"),
        ("ALL", "Lek"),
        ("AMD", "Arman dramasi"),
        ("ANG", "Niderlandiya Antil guldeni"),
        ("AOA", "Kvanza"),
        ("ARS", "Argentina pesosi"),
        ("AUD", "Avstraliya dollari"),
        ("AWG", "Aruba florini"),
        ("AZN", "Ozarbayjon manati"),
        ("BAM", "Bosniya va Gertsegovina konvertatsiya qilinadigan markasi"),
        ("BBD", "Barbados dollari"),
        ("BDT", "Taka"),
        ("BGN", "Bolgariya levi"),
        ("BHD", "Bahrayn dinori"),
        ("BIF", "Burundi franki"),
        ("BMD", "Bermuda dollari"),
        ("BND", "Bruney dollari"),
        ("BOB", "Boliviano"),
        ("BRL", "Braziliya reali"),
        ("BSD", "Bagama dollari"),
        ("BTN", "Ngultrum"),
        ("BWP", "Pula"),
        ("BYR", "Belarus rubli"),
        ("BZD", "Beliz dollari"),
        ("CAD", "Kanada dollari"),
        ("CDF", "Kongo franki"),
        ("CHF", "Shveytsariya franki"),
        ("CLP", "Chili pesosi"),
        ("CNY", "Yuan"),
        ("COP", "Kolumbiya pesosi"),
        ("CRC", "Kosta-Rika koloni"),
        ("CUC", "Kuba konvertatsiya qilinadigan pesosi"),
        ("CUP", "Kuba pesosi"),
        ("CVE", "Kabo-Verde eskudosi"),
        ("CZK", "Chex kronasi"),
        ("DJF", "Jibuti franki"),
        ("DKK", "Daniya kronasi"),
        ("DOP", "Dominikan pesosi"),
        ("DZD", "Jazoir dinori"),
        ("EGP", "Misr funti"),
        ("ERN", "Nakfa"),
        ("ETB", "Efiopiya biri"),
        ("EUR", "Yevro"),
        ("FJD", "Fiji dollari"),
        ("FKP", "Folklend orollari funti"),
        ("GBP", "Funt sterling"),
        ("GEL", "Lari"),
        ("GGP", "Gernsi funti"),
        ("GHS", "Gana sedi"),
        ("GIP", "Gibraltar funti"),
        ("GMD", "Dalasi"),
        ("GNF", "Gvineya franki"),
        ("GTQ", "Ketsal"),
        ("GYD", "Gayana dollari"),
        ("HKD", "Gonkong dollari"),
        ("HNL", "Lempira"),
        ("HRK", "Xorvatiya kunasi"),
        ("HTG", "Gurda"),
        ("HUF", "Forint"),
        ("IDR", "Indoneziya rupiyasi"),
        ("ILS", "Yangi Isroil shekeli"),
        ("NIS", "Yangi Isroil shekeli"),
        ("IMP", "Men oroli funti"),
        ("INR", "Hind rupiyasi"),
        ("IQD", "Iroq dinori"),
        ("IRR", "Eron riali"),
        ("ISK", "Islandiya kronasi"),
        ("JEP", "Jersi funti"),
        ("JMD", "Yamayka dollari"),
        ("JOD", "Iordaniya dinori"),
        ("JPY", "Yena"),
        ("KES", "Keniya shillingi"),
        ("KGS", "Som"),
        ("KHR", "Riyel"),
        ("KMF", "Komor franki"),
        ("KPW", "Shimoliy Koreya voni"),
        ("KRW", "Janubiy Koreya voni"),
        ("KWD", "Kuvayt dinori"),
        ("KYD", "Kayman orollari dollari"),
        ("KZT", "Tenge"),
        ("LAK", "Kip"),
        ("LBP", "Livan funti"),
        ("LKR", "Shri-Lanka rupiyasi"),
        ("LRD", "Liberiya dollari"),
        ("LSL", "Loti"),
        ("LTL", "Litva liti"),
        ("LYD", "Liviya dinori"),
        ("MAD", "Marokash dirhami"),
        ("MDL", "Moldaviya leyi"),
        ("MGA", "Malagasi ariari"),
        ("MKD", "Denar"),
        ("MMK", "Kyat"),
        ("MNT", "Tugrik"),
        ("MOP", "Pataka"),
        ("MRO", "Ugiyya"),
        ("MUR", "Mavrikiy rupiyasi"),
        ("MVR", "Rufiya"),
        ("MWK", "Kvacha"),
        ("MXN", "Meksika pesosi"),
        ("MYR", "Malayziya ringgiti"),
        ("MZN", "Mozambik metikali"),
        ("NAD", "Namibiya dollari"),
        ("NGN", "Nayra"),
        ("NIO", "Kordoba"),
        ("NOK", "Norvegiya kronasi"),
        ("NPR", "Nepal rupiyasi"),
        ("NZD", "Yangi Zelandiya dollari"),
        ("OMR", "Ummon riali"),
        ("PAB", "Balboa"),
        ("PEN", "Sol"),
        ("PGK", "Kina"),
        ("PHP", "Filippin pesosi"),
        ("PKR", "Pokiston rupiyasi"),
        ("PLN", "Zlotiy"),
        ("PYG", "Guarani"),
        ("QAR", "Qatar riali"),
        ("RON", "Ruminiya leyi"),
        ("RSD", "Serbiya dinori"),
        ("RUB", "Rossiya rubli"),
        ("RWF", "Ruanda franki"),
        ("SAR", "Saudiya riyoli"),
        ("SBD", "Solomon orollari dollari"),
        ("SCR", "Seyshel rupiyasi"),
        ("SDG", "Sudan funti"),
        ("SEK", "Shvetsiya kronasi"),
        ("SGD", "Singapur dollari"),
        ("SHP", "Muqaddas Yelena funti"),
        ("SLL", "Leone"),
        ("SOS", "Somali shillingi"),
        ("SPL", "Luigino"),
        ("SRD", "Surinam dollari"),
        ("STD", "Dobra"),
        ("SVC", "Salvador koloni"),
        ("SYP", "Suriya funti"),
        ("SZL", "Lilangeni"),
        ("THB", "Bat"),
        ("TJS", "Somoniy"),
        ("TMT", "Yangi Turkman manati"),
        ("TND", "Tunis dinori"),
        ("TOP", "Paanga"),
        ("TRY", "Turk lirasi"),
        ("TTD", "Trinidad va Tobago dollari"),
        ("TVD", "Tuvalu dollari"),
        ("TWD", "Yangi Tayvan dollari"),
        ("TZS", "Tanzaniya shillingi"),
        ("UAH", "Grivna"),
        ("UGX", "Uganda shillingi"),
        ("USD", "AQSh dollari"),
        ("UYU", "Urugvay pesosi"),
        ("UZS", "Oʻzbek so‘mi"),
        ("VEF", "Suveren bolivar"),
        ("VND", "Dong"),
        ("VUV", "Vatu"),
        ("WST", "Tala"),
        ("XAF", "KFA franki BEAS"),
        ("XCD", "Sharqiy Karib dollari"),
        ("XDR", "SDR"),
        ("XOF", "KFA franki BCEAO"),
        ("XPF", "KFP franki"),
        ("YER", "Yaman riali"),
        ("ZAR", "Rand"),
        ("ZMW", "Zambiya kvachasi"),
        ("ZWD", "Zimbabve dollari"),
    )

    price_formats = ["#,##", "%#,##", "%##,##", "% ###,##", "%# ###,##"]

    def pricetag(self) -> str:
        return (
            self.numerify(self.random_element(self.price_formats)) + "\N{NO-BREAK SPACE}\N{CYRILLIC SMALL LETTER ER}."
        )



from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """Color provider for mk_MK locale (Macedonian).

    Sources:
    - https://mk.wikipedia.org/wiki/Боја (spectrum colors with hex codes)
    - Standard Macedonian color terminology with CSS/web hex values
    """

    all_colors = OrderedDict(
        (
            ("Црвена", "#FF0000"),
            ("Портокалова", "#FF6600"),
            ("Жолта", "#FFFF00"),
            ("Зелена", "#008000"),
            ("Сина", "#0000FF"),
            ("Виолетова", "#8000FF"),
            ("Бела", "#FFFFFF"),
            ("Црна", "#000000"),
            ("Сива", "#808080"),
            ("Кафеава", "#8B4513"),
            ("Розова", "#FFC0CB"),
            ("Тиркизна", "#40E0D0"),
            ("Кармин", "#DC143C"),
            ("Лимонова", "#FFF44F"),
            ("Маслинова", "#808000"),
            ("Темноцрвена", "#8B0000"),
            ("Темносина", "#00008B"),
            ("Темнозелена", "#006400"),
            ("Светлосина", "#ADD8E6"),
            ("Светлозелена", "#90EE90"),
            ("Светлосива", "#D3D3D3"),
            ("Темносива", "#A9A9A9"),
            ("Сребрена", "#C0C0C0"),
            ("Златна", "#FFD700"),
            ("Бронзена", "#CD7F32"),
            ("Индиго", "#4B0082"),
            ("Лавандула", "#E6E6FA"),
            ("Корал", "#FF7F50"),
            ("Лосос", "#FA8072"),
            ("Магента", "#FF00FF"),
            ("Цијан", "#00FFFF"),
            ("Мастилена", "#000080"),
            ("Бордо", "#800020"),
            ("Бежова", "#F5F5DC"),
            ("Теракота", "#E2725B"),
            ("Охра", "#CC7722"),
            ("Слонова коска", "#FFFFF0"),
            ("Нане", "#98FF98"),
            ("Рубин", "#9B111E"),
            ("Смарагдна", "#50C878"),
            ("Аквамарин", "#7FFFD4"),
            ("Чоколадова", "#D2691E"),
        )
    )

    safe_colors = (
        "црна",
        "кестенлива",
        "зелена",
        "маслинова",
        "виолетова",
        "цијан",
        "сина",
        "сребрена",
        "сива",
        "жолта",
        "бела",
    )



import inspect
import warnings

from enum import Enum, auto
from typing import Any, Dict, List, Optional, Tuple, Type, Union

from .generator import Generator
from .providers import BaseProvider
from .proxy import Faker


class FakerEnum(Enum):
    """Required for faker.providers.enum"""

    A = auto
    B = auto


class Documentor:
    def __init__(self, generator: Union[Generator, Faker]) -> None:
        """
        :param generator: a localized Generator with providers filled,
                          for which to write the documentation
        :type generator: faker.Generator()
        """
        self.generator = generator
        self.max_name_len: int = 0
        self.already_generated: List[str] = []

    def get_formatters(
        self,
        locale: Optional[str] = None,
        excludes: Optional[List[str]] = None,
        **kwargs: Any,
    ) -> List[Tuple[BaseProvider, Dict[str, str]]]:
        self.max_name_len = 0
        self.already_generated = [] if excludes is None else excludes[:]
        formatters = []
        providers: List[BaseProvider] = self.generator.get_providers()
        for provider in providers[::-1]:  # reverse
            if locale and provider.__lang__ and provider.__lang__ != locale:
                continue
            formatters.append(
                (provider, self.get_provider_formatters(provider, **kwargs)),
            )
        return formatters

    def get_provider_formatters(
        self,
        provider: BaseProvider,
        prefix: str = "fake.",
        with_args: bool = True,
        with_defaults: bool = True,
    ) -> Dict[str, str]:
        formatters = {}

        for name, method in inspect.getmembers(provider, inspect.ismethod):
            # skip 'private' method and inherited methods
            if name.startswith("_") or name in self.already_generated:
                continue

            arguments = []
            faker_args: List[Union[str, Type[Enum]]] = []
            faker_kwargs = {}

            if name == "binary":
                faker_kwargs["length"] = 1024
            elif name in ["zip", "tar"]:
                faker_kwargs.update(
                    {
                        "uncompressed_size": 1024,
                        "min_file_size": 512,
                    }
                )

            if name == "enum":
                faker_args = [FakerEnum]

            if with_args:
                # retrieve all parameter
                argspec = inspect.getfullargspec(method)

                lst = [x for x in argspec.args if x not in ["self", "cls"]]
                for i, arg in enumerate(lst):
                    if argspec.defaults and with_defaults:
                        try:
                            default = argspec.defaults[i]
                            if isinstance(default, str):
                                default = repr(default)
                            else:
                                # TODO check default type
                                default = f"{default}"

                            arg = f"{arg}={default}"

                        except IndexError:
                            pass

                    arguments.append(arg)
                    if with_args == "first":
                        break

                if with_args != "first":
                    if argspec.varargs:
                        arguments.append("*" + argspec.varargs)
                    if argspec.varkw:
                        arguments.append("**" + argspec.varkw)

            # build fake method signature
            signature = f"{prefix}{name}({', '.join(arguments)})"

            try:
                # make a fake example
                example = self.generator.format(name, *faker_args, **faker_kwargs)
            except (AttributeError, ValueError) as e:
                warnings.warn(str(e))
                continue
            formatters[signature] = example

            self.max_name_len = max(self.max_name_len, *(len(part) for part in signature.split()))
            self.already_generated.append(name)

        return formatters

    @staticmethod
    def get_provider_name(provider_class: BaseProvider) -> str:
        return provider_class.__provider__



from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    """Phone number provider for `de_AT` locale.

    Sources:
    - https://de.wikipedia.org/wiki/Telefonvorwahl_(%C3%96sterreich)

    """

    dialing_codes = (
        "650",
        "655",
        "660",
        "661",
        "663",
        "664",
        "665",
        "667",
        "670",
        "676",
        "677",
        "678",
        "680",
        "681",
        "688",
        "690",
        "699",
    )

    area_code_formats = (
        "1",  # Wien
        "316",  # Graz
        "463",  # Klagenfurt
        "512",  # Innsbruck
        "662",  # Salzburg
        "732",  # Linz
        "21##",
        "22##",
        "25##",
        "26##",
        "27##",
        "28##",
        "29##",
        "31##",
        "33##",
        "34##",
        "35##",
        "36##",
        "38##",
        "42##",
        "43##",
        "47##",
        "48##",
        "52##",
        "53##",
        "54##",
        "55##",
        "56##",
        "61##",
        "62##",
        "64##",
        "65##",
        "72##",
        "73##",
        "74##",
        "75##",
        "76##",
        "77##",
        "79##",
    )

    cellphone_formats = (
        "+43 (0) {{dialing_code}} ########",
        "+43 {{dialing_code}} ### ### ##",
        "+43 {{dialing_code}}########",
        "0{{dialing_code}} ### ### ##",
        "0{{dialing_code}}/########",
    )

    landline_formats = (
        "+43 (0) {{area_code}} ########",
        "+43 {{area_code}} ##### ###",
        "+43 {{area_code}}########",
        "0{{area_code}} ##### ###",
        "(0{{area_code}}) ##### ###",
        "0{{area_code}}/########",
    )

    """
        Get dialing code for cellphone numbers.
    """

    def dialing_code(self) -> str:
        return self.random_element(self.dialing_codes)

    """
        Get area code for landlines.
    """

    def area_code(self) -> str:
        area_code: str = self.random_element(self.area_code_formats)
        return self.numerify(area_code)

    """
        Get a landline phone number.
    """

    def phone_number(self) -> str:
        pattern: str = self.random_element(self.landline_formats)
        return self.numerify(self.generator.parse(pattern))

    """
        Get a cellphone number.
    """

    def cellphone_number(self) -> str:
        pattern: str = self.random_element(self.cellphone_formats)
        return self.numerify(self.generator.parse(pattern))



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    """Company provider for mk_MK locale (Macedonian)."""

    formats = (
        "{{last_name}} {{company_suffix}}",
        "{{last_name}} {{last_name}} {{company_suffix}}",
        "{{last_name}}",
        "{{last_name}} и {{last_name}} {{company_suffix}}",
    )

    company_suffixes = (
        "АД",
        "ДОО",
        "ДООЕЛ",
        "ЕД",
        "КД",
        "ТД",
        "ЈП",
        "ООД",
    )
